package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@(!`0D```````````(`/@`!````L!]```````!``````````+C%````
M`````````$``.``'`$``&@`9``8````%````0`````````!``$```````$``
M0```````B`$```````"(`0````````@``````````P````0```#(`0``````
M`,@!0```````R`%````````5`````````!4``````````0`````````!````
M!0````````````````!``````````$```````.!7````````X%<`````````
M`!````````$````&`````&``````````8%````````!@4```````H&,`````
M``"H:```````````$````````@````8```"0OP```````)"_4```````D+]0
M``````#P`0```````/`!````````"``````````$````!````.`!````````
MX`%```````#@`4```````!@`````````&``````````$`````````%#E=&0$
M````V%<```````#85T```````-A70```````"``````````(``````````0`
M````````+VQI8F5X96,O;&0M96QF+G-O+C$`````"`````0````!````1G)E
M94)31`#H.`P`80```&<`````````.P`````````)`````````%T```!<````
M6```````````````90````````!%````6P`````````V````/P```#D````.
M````-0```$D```!0````1@```````````````````"````!9````+0````$`
M````````,````%(````K````80`````````&````&0```&(````:````````
M`"D`````````8``````````L````7P````````!+````)P````4```!.````
M9````#T```!"````)````%4````7````9@`````````O````'P````````!(
M`````````````````````````%$```!$````,P```%<```!>````'0``````
M`````````````%8````Q````0````%0```!:````#0`````````/````!```
M`````````````````#<`````````'@```!,`````````*@```&,`````````
M````````````````````````````````````````````````````````````
M``````````P`````````````````````````````````````````````````
M`````````````!$````#````&`````@```````````````L`````````````
M```````````````````````````````````````H`````````!P`````````
M"@```"$`````````(P`````````````````````````"````````````````
M`````````#0````````````````````\```````````````0````````````
M```X```````````````B````&P````<````F`````````$$````E````````
M```````^`````````#H```!-````+@``````````````,@```!8```!,````
M0P`````````2`````````!4```!3````3P``````````````2@```!0`````
M````1P````````````````````````````````````P````2````[!M`````
M``"-`````````.4"```2````_!M```````"0`````````!<````2````#!Q`
M``````#;!P```````"D````1`!<`H,-0```````!`````````((#```2````
M'!Q````````/`````````-8#```2``P`4#Y```````"^`0```````$`````1
M`/'_D+]0`````````````````/@"```2````+!Q```````````````````4#
M```2````/!Q````````T`````````#X#```2````3!Q```````!5````````
M`$D````2````7!Q```````"1`P```````%<````2````;!Q```````"Z````
M`````&,````2````?!Q````````/`0```````.,#```2``P`4%!````````%
M`````````'0````1`!<`J,-0```````(`````````(8"```1`!<`L,-0````
M``!``````````'X````2````C!Q```````!,!P```````(T````1`!<`\,-0
M```````(`````````/0#```2``P`0#A```````!-`````````)<````2````
MG!Q````````*`P````````($```2``P`0$!```````#B`````````$P#```2
M````K!Q````````"`````````!P#```2````O!Q```````#(#````````*4`
M```1`!<`^,-0```````!`````````#,$```2``H`R!M`````````````````
M`+(````2````S!Q```````!#!0```````+T````2````W!Q```````"0````
M`````,H````2````[!Q```````!A`0```````-@````1`!<`H,A0```````(
M`````````.`````2````_!Q```````"8`@````````T#```2````#!U`````
M``!,`````````!4#```2````'!U```````````````````X$```2``P`D$-`
M``````"L`0```````.L````2````+!U```````!G`````````!L$```2``P`
M8%!```````#<`@```````#$$```2``P`0%-````````4`````````#<#```2
M````/!U````````,`````````.T"```1`!```&!0```````(`````````*0#
M```2``P`L!]```````"<`````````'0#```2````3!U`````````````````
M`/D"```2````7!U``````````````````%8#```2````;!U````````*````
M`````$4#```2````?!U```````!4`````````#D$```2``P`0$5````````\
M"@```````/H````2````C!U````````$!````````,`"```2````G!U`````
M`````````````$X"```2````K!U````````Q`````````,X"```2````O!U`
M``````!G`````````$8$```2``P`,$%```````!M`````````/X"```2````
MS!U```````!\``````````,!```1`!<`^<-0```````!`````````%X#```2
M````W!U```````!^`````````!$!```2````[!U````````C!````````"$!
M```1`!<``,10```````(`````````)\#```0`/'_H,-0````````````````
M`&`"```2````_!U```````!#`````````%($```2``P`H$%```````#P`0``
M`````%<$```2``P`,#U````````7`0```````'`"```1`!<`",10```````$
M`````````&D$```2``P`@$]```````#)`````````#$!```1`!<`#,10````
M```!`````````#P!```2``T`N%-``````````````````$(!```2````#!Y`
M``````!9'````````+H$```2````'!Y````````>`````````"0#```1`!<`
M$,10```````(`````````%L"```2````+!Y```````"4`````````'X"```2
M````/!Y```````!*`````````%`!```2````3!Y```````!"`````````&\#
M```2````7!Y````````O`````````)(#```2````;!Y`````````````````
M``P"```2````?!Y````````\!@```````&`!```2````C!Y````````K````
M`````)@#```0`/'_H,-0`````````````````)\"```2````G!Y```````!*
M`````````&L!```1`/'_J,%0`````````````````*L#```0`/'_J,A0````
M`````````````,8"```2````K!Y```````!L`````````($!```1`!<`&,10
M```````!`````````(P!```1`!<`(,10```````3`````````*8"```1`!<`
M.,10```````(`````````!@"```2````O!Y````````O!P```````+D"```2
M````S!Y``````````````````'\$```2``P`D#A````````>`````````)L!
M```2````W!Y```````![`````````-0"```2````[!Y````````,````````
M`)L$```2``P`P"!````````T`````````+(!```1`!<`0,10```````(````
M`````&T#```2````_!Y````````O`````````*@$```2``P`$$!````````B
M`````````+@!```1`!<`2,10```````(`````````)@"```2````#!]`````
M`````````````,,!```2````'!]```````!Q`@```````-$!```1`!<`4,10
M```````(`````````'L#```2````+!]```````#T`````````(D#```2````
M/!]```````";`````````%8"```2````3!]```````!G`````````-X!```@
M`````````````````````````&4#```2````7!]```````"0`````````/(!
M```2````;!]````````6`````````+`"```2````?!]`````````````````
M```"```2````C!]````````V`````````!,"```2````G!]````````5````
M``````!L:6)P97)L+G-O`%!E<FQ?8W)O86L`4&5R;%]S=E\R<'9?9FQA9W,`
M4$Q?<&5R;%]D97-T<G5C=%]L979E;`!?1%E.04U)0P!097)L7V%V7W-H:69T
M`%!E<FQ?;6=?<V5T`%!E<FQ?;F5W6%-?9FQA9W,`4$Q?8V]M<&-V`'!E<FQ?
M8V]N<W1R=6-T`%!,7W!A<G-E<@!097)L7V1O=6YW:6YD`%!,7V1O7W5N9'5M
M<`!P97)L7W!A<G-E`%!E<FQ?;F5W4U9P=@!097)L7W-V7W-E='!V`&5N=FER
M;VX`4&5R;%]N97=84P!097)L7W-Y<U]I;FET,P!P97)L7W)U;@!03%]E>&ET
M7V9L86=S`&)O;W1?1'EN84QO861E<@!03%]C=7)S=&%C:VEN9F\`4$Q?=&%I
M;G1E9`!?9FEN:0!P97)L7V1E<W1R=6-T`%!E<FQ?9W9?9F5T8VAP=@!P97)L
M7V%L;&]C`%]'3$]"04Q?3T9&4T547U1!0DQ%7P!03%]I;E]E=F%L`%!,7VUE
M;6]R>5]W<F%P`%!E<FQ?<V%V95]D97-T<G5C=&]R7W@`4$Q?;W``4$Q?=&]P
M7V5N=@!097)L7V%V7V9E=&-H`%!,7V5V86Q?<F]O=`!?2G9?4F5G:7-T97)#
M;&%S<V5S`%!E<FQ?<WES7W1E<FT`4&5R;%]S869E<WES;6%L;&]C`'!E<FQ?
M9G)E90!L:6)M+G-O+C4`;&EB8W)Y<'0N<V\N-0!L:6)U=&EL+G-O+C@`;&EB
M=&AR+G-O+C,`7U]E<G)O<@!R96%D`&]P96X`8VQO<V4`;&EB8RYS;RXW`%]?
M;6)?<V)?;&EM:70`;65M;6]V90!?7W-T86-K7V-H:U]G=6%R9`!G971P:60`
M;65M8W!Y`%]?<W1D97)R<`!R96%D;&EN:P!G971U:60`<FUD:7(`<F5A9&1I
M<@!L<V5E:P!?7W-T86-K7V-H:U]F86EL`&9P<FEN=&8`7U]P<F]G;F%M90!L
M<W1A=`!S=')S='(`<W1R;F-M<`!S=')N8W!Y`'5N;&EN:P!R96%L;&]C`%]#
M=7)R96YT4G5N94QO8V%L90!S=')T;VL`<W1R9'5P`&UE;7-E=`!?:6YI=%]T
M;',`;W!E;F1I<@!S=')C;7``<W!R:6YT9@!A=&5X:70`86-C97-S`'-T<FQE
M;@!E>&5C=G``8VQO<V5D:7(`;6MD:7(`7V5D871A`%]?8G-S7W-T87)T`%]E
M;F0`+W5S<B]L;V-A;"]L:6(O<&5R;#4O-2XQ,BXT+VUA8V@O0T]210!P87)?
M:6YI=%]E;G8`<&%R7V-U<G)E;G1?97AE8P!P87)?96YV7V-L96%N`'!A<E]D
M:7)N86UE`'!A<E]F:6YD<')O9P!84U]);G1E<FYA;'-?4$%27T)/3U0`>'-?
M:6YI=`!P87)?;6MT;7!D:7(`<&%R7V-L96%N=7``;6%I;@!P87)?<V5T=7!?
M;&EB<&%T:`!P87)?8W5R<F5N=%]E>&5C7W!R;V,`6%-?26YT97)N86QS7U!!
M4E]#3$5!4E-404-+`'!A<E]B87-E;F%M90!G971?=7-E<FYA;65?9G)O;5]G
M971P=W5I9`!&0E-$7S$N,````````@```````@`!``$``@`"``(`````````
M`0````(```````$````!``(``@````$``````````0````(``@`!`````0`!
M``(``0`!``(``@`"``(``0````(``P`"``$``@````(```````$``P`!``$`
M`@`!`````0````(``@`#``(````"``(``@````$``@`!``$``@```````@`"
M``(``0````(``0````(``0````(```````(``@`#`````@````(`````````
M``````$``0!"`@``$````"````"P*'H'```#`,,$`````````0`!`&8"```0
M`````````+`H>@<```(`PP0```````"@PU````````4````$````````````
M``"HPU````````4````/``````````````"PPU````````4````0````````
M``````#PPU````````4````2``````````````#XPU````````4````8````
M``````````#YPU````````4````S````````````````Q%````````4````V
M```````````````(Q%````````4````[```````````````,Q%````````4`
M```]```````````````0Q%````````4```!!```````````````8Q%``````
M``4```!.```````````````@Q%````````4```!/```````````````XQ%``
M``````4```!0``````````````!`Q%````````4```!7``````````````!(
MQ%````````4```!:``````````````!0Q%````````4```!=````````````
M``#`P5````````<````!``````````````#(P5````````<````"````````
M``````#0P5````````<````#``````````````#8P5````````<````%````
M``````````#@P5````````<````(``````````````#HP5````````<````)
M``````````````#PP5````````<````*``````````````#XP5````````<`
M```+````````````````PE````````<````,```````````````(PE``````
M``<````-```````````````0PE````````<````1```````````````8PE``
M``````<````4```````````````@PE````````<````6```````````````H
MPE````````<````7```````````````PPE````````<````:````````````
M```XPE````````<````;``````````````!`PE````````<````<````````
M``````!(PE````````<````>``````````````!0PE````````<````?````
M``````````!8PE````````<````@``````````````!@PE````````<````B
M``````````````!HPE````````<````E``````````````!PPE````````<`
M```H``````````````!XPE````````<````I``````````````"`PE``````
M``<````J``````````````"(PE````````<````K``````````````"0PE``
M``````<````M``````````````"8PE````````<````N``````````````"@
MPE````````<````O``````````````"HPE````````<````P````````````
M``"PPE````````<````R``````````````"XPE````````<````T````````
M``````#`PE````````<````U``````````````#(PE````````<````X````
M``````````#0PE````````<````_``````````````#8PE````````<```!`
M``````````````#@PE````````<```!"``````````````#HPE````````<`
M``!#``````````````#PPE````````<```!$``````````````#XPE``````
M``<```!%````````````````PU````````<```!&```````````````(PU``
M``````<```!'```````````````0PU````````<```!(```````````````8
MPU````````<```!*```````````````@PU````````<```!-````````````
M```HPU````````<```!1```````````````PPU````````<```!2````````
M```````XPU````````<```!4``````````````!`PU````````<```!5````
M``````````!(PU````````<```!8``````````````!0PU````````<```!;
M``````````````!8PU````````<```!<``````````````!@PU````````<`
M``!>``````````````!HPU````````<```!?``````````````!PPU``````
M``<```!@``````````````!XPU````````<```!B``````````````"`PU``
M``````<```!C``````````````"(PU````````<```!D``````````````"0
MPU````````<```!E``````````````"8PU````````<```!F````````````
M``!(@^P(Z+\$``#HNC<``$B#Q`C#`/\USJ40`/\ET*40`)"0D)#_)<ZE$`!H
M`````.G@_____R7&I1``:`$```#IT/____\EOJ40`&@"````Z<#_____);:E
M$`!H`P```.FP_____R6NI1``:`0```#IH/____\EIJ40`&@%````Z9#_____
M)9ZE$`!H!@```.F`_____R66I1``:`<```#I</____\ECJ40`&@(````Z6#_
M____)8:E$`!H"0```.E0_____R5^I1``:`H```#I0/____\E=J40`&@+````
MZ3#_____)6ZE$`!H#````.D@_____R5FI1``:`T```#I$/____\E7J40`&@.
M````Z0#_____)5:E$`!H#P```.GP_O___R5.I1``:!````#IX/[___\E1J40
M`&@1````Z=#^____)3ZE$`!H$@```.G`_O___R4VI1``:!,```#IL/[___\E
M+J40`&@4````Z:#^____)2:E$`!H%0```.F0_O___R4>I1``:!8```#I@/[_
M__\E%J40`&@7````Z7#^____)0ZE$`!H&````.E@_O___R4&I1``:!D```#I
M4/[___\E_J00`&@:````Z4#^____)?:D$`!H&P```.DP_O___R7NI!``:!P`
M``#I(/[___\EYJ00`&@=````Z1#^____)=ZD$`!H'@```.D`_O___R76I!``
M:!\```#I\/W___\ESJ00`&@@````Z>#]____)<:D$`!H(0```.G0_?___R6^
MI!``:"(```#IP/W___\EMJ00`&@C````Z;#]____):ZD$`!H)````.F@_?__
M_R6FI!``:"4```#ID/W___\EGJ00`&@F````Z8#]____)9:D$`!H)P```.EP
M_?___R6.I!``:"@```#I8/W___\EAJ00`&@I````Z5#]____)7ZD$`!H*@``
M`.E`_?___R5VI!``:"L```#I,/W___\E;J00`&@L````Z2#]____)6:D$`!H
M+0```.D0_?___R5>I!``:"X```#I`/W___\E5J00`&@O````Z?#\____)4ZD
M$`!H,````.G@_/___R5&I!``:#$```#IT/S___\E/J00`&@R````Z<#\____
M)3:D$`!H,P```.FP_/___R4NI!``:#0```#IH/S___\E)J00`&@U````Z9#\
M____)1ZD$`!H-@```.F`_/___R46I!``:#<```#I</S___\E#J00`&@X````
MZ6#\____)0:D$`!H.0```.E0_/___R7^HQ``:#H```#I0/S___\E]J,0`&@[
M````Z3#\__\`````54B)Y4%53(UO"$%44TB#[`B+'TACPX7;3(UDQQ!,B27,
MJ!``?CI(BU<(2(72=#%(B14:0!``#[8"A,!T(TB#P@$\+TB+!09`$`!(#T3"
M2(D%^S\0``^V`DB#P@&$P'7AN)"_4`!(A<!T*TB)]^C:_O__O[A30`#HT/[_
M_^B7^___B=],B>),B>[H8B$``(G'Z!?^___H8OS__^O6D)"0D$B#[`B`/?VC
M$```=!#K))!(@\`(2(D%I3\0`/_22(L%G#\0`$B+$$B%TG7DQ@75HQ```4B#
MQ`C#9F9FD&9F9I!(@ST(H1```'06N`````!(A<!T#+^@P5``28G#0?_CD//#
MD)"0D)"0D)"0D)"0D)`/M@](B?B$R70H2(L%7S4``$B-5P$/MC!(B?AF9I!F
MD$`X\0^V"D@/1,)(@\(!A,EU[O/#9F9FD&9F9I!F9F:0059(C7<X055!5%5(
MB?U32('L"`(``$R-3"2(38V!@````$R)STB+#DB#Q@A(B<I(B<A(P>((2,'@
M&"4```#_@>(``/\`2`G"2(G(2,'H""4`_P``2`G"2(G(2,'H&"7_````2`G"
M2(G(2,'I*$C!Z"!(B1=(P>`(2(G"2,'@$"4```#_@>(``/\`2`G"2(G(2,'I
M$"4`_P``2`G"2`G*2(E7"$B#QQ!,.<</A77___])C4EH28VQ:`(``&9FD&:0
M2(L!2#-!V$@S0:A(,T&82(G"2`'`2,'J'T@)PH/B_TB)41A(@\$(2#GQ==1,
MBW4`2(M\)(A!O=R\&X](`WT@2(M-"$R+51!(BW483(GP3(GR38GQ2,'B!4C!
MZ!M)B<A("=!,B=))P>@"@^#_2"'*2<'I`DB-O`>9>8):2(G(2,'A'DCWT$D)
MR$@A\$&#X/](`W0DD$@)T$R)P@''3(GP3"'R2/?02(GY3"'02,'I&TP#5"28
M2`G"2(GX2,'@!4B-M!:9>8):2(GZ2`G!3(GP2,'@'@'Q20G!2(GX2(G.08/A
M_TCWT$C![AM,(<I,(<!("=!(B<I-C90"F7F"6DB)R$C!X`5("<9(B<A$`=9)
MB?I(]]!)P>H"2,'G'DP#1"2@20GZ3"'(2(GW08/B_TC![QM,`TPDJ$PATD@)
MT$B)\DV-A`"9>8):2(GP2,'@!4@)QTB)\$0!QTF)R$C!X1Y)P>@"2/?020G(
M3"'02(GY08/@_TC!Z1M,`U0DL$PAPD@)T$B)^DV-C`&9>8):2(GX2,'@!4@)
MP4B)^$0!R4F)\4C!YAY)P>D"2/?020GQ3"'`2(G.08/A_TC![AM,(<I("=!(
MB<I-C90"F7F"6DB)R$C!X`5,`T0DN$@)QDB)R$0!UDF)^DC!YQY)P>H"2/?0
M20GZ3"'(2(GW08/B_TC![QM,`TPDP$PATD@)T$B)\DV-A`"9>8):2(GP2,'@
M!4@)QTB)\$0!QTF)R$C!X1Y)P>@"2/?020G(3"'02(GY08/@_TC!Z1M,`U0D
MR$PAPD@)T$B)^DV-C`&9>8):2(GX2,'@!4@)P4B)^$0!R4F)\4C!YAY)P>D"
M2/?020GQ3"'`2(G.08/A_TPARDC![AM,`T0DT$@)T$B)RDV-E`*9>8):2(G(
M2,'@!4@)QDB)R$0!UDF)^DC!YQY)P>H"2/?020GZ3"'(2(GW08/B_TC![QM,
M`TPDV$PATD@)T$B)\DV-A`"9>8):2(GP2,'@!4@)QTB)\$0!QTF)R$C!X1Y)
MP>@"2/?020G(3"'02(GY08/@_TC!Z1M,(<)("=!(B?I-C8P!F7F"6DB)^$C!
MX`5("<%(B?A$`<E)B?%(P>8>2<'I`DCWT$D)\4B)SD&#X?],`U0DX$PAP$PA
MRDC![AM,`T0DZ$@)T$B)RDV-E`*9>8):2(G(2,'@!4@)QDB)R$0!UDF)^DC!
MYQY)P>H"2/?020GZ3"'(2(GW08/B_TC![QM,`TPD\$PATD@)T$B)\DV-A`"9
M>8):2(GP2,'@!4@)QTB)\$0!QTF)R$C!X1Y)P>@"2/?020G(3"'02(GY08/@
M_TC!Z1M,(<)("=!(B?I-C8P!F7F"6DB)^$C!X`5("<%(B?A$`<E)B?%(]]!)
MP>D"2,'F'DP#5"3X20GQ3"'`2(G.08/A_TC![AM,`P0D3"'*2`G02(G*38V4
M`IEY@EI(B<A(P>`%2`G&2(G(1`'628GZ2,'G'DG!Z@)(]]!)B?-)"?I,(<A(
MB?=!@^+_2,'O&TP#3"0(3"'22`G02(GR38V$`)EY@EI(B?!(P>`%2`G'2(GP
M1`''28G(2,'A'DG!Z`)(]]!)"<A,(=!(B?E!@^#_2,'I&TPAPD@)T$B)^DV-
MC`&9>8):2(GX2,'@!4C!YAY)P>L"3`-4)!!("<%)"?-(B?A!@^/_1`')2/?0
M3"':2(G.3"'`28GY2,'N&T@)T$C!YQY)P>D"38V4`IEY@EI(B<A,`T0D&$C!
MX`5)"?E(B<I("<9(B<A!@^'_2/?03"'*1`'63"'82(GW28G*2`G02,'A'DC!
M[QM-C80`F7F"6DB)\$G!Z@)(P>`%3`-<)"!)"<I("<=(B?!!@^+_2(GR2/?0
M1`''3"'(28GP3"'22`G02,'F'DG!Z`)-C9P#F7F"6DD)\$B)^DB)^$&#X/],
M`TPD*$C!X`5(P>H;2`G"3(G`3#'01`':3`-4)#!(,?A(B=%-C8P!H>O9;DB)
MT$C!Z1M(P>`%2`G!1`')28GY2,'G'DG!Z0)(B<Y)"?E(B==(P>X;08/A_TC!
M[P),B<A,,<!,`T0D.$@QT$C!XAY-C90"H>O9;D@)UTB)R(/G_TC!X`5("<9(
MB?A$`=9,,<A,`TPD0$@QR$B)\DV-A`"AZ]EN2(GP2,'J&TC!X`5("<)$`<))
MB<A(P>$>2<'H`DD)R$B)T4&#X/](P>D;3(G`2#'X2`-\)$A(,?!-C8P!H>O9
M;DB)T$C!X`5("<%$`<E)B?%(P>8>2<'I`DD)\4B)SD&#X?](P>X;3(G(3#'`
M3`-$)%!(,=!(C;P'H>O9;DB)R$C!X`5("<8!_DB)UTC!XAY(P>\"2`G72(GR
M@^?_2(GX3#'(2,'J&TP#3"182#'(38V$`*'KV6Y(B?!(P>`%2`G"1`'"28G(
M2,'A'DG!Z`))"<A(B=%!@^#_2,'I&TR)P$@Q^$@#?"1@2#'P38V,`:'KV6Y(
MB=!(P>`%2`G!1`')28GQ2,'F'DG!Z0))"?%(B<Y!@^'_2,'N&TR)R$PQP$P#
M1"1H2#'02(V\!Z'KV6Y(B<A(P>`%2`G&`?Y(B==(P>(>2,'O`D@)UTB)\H/G
M_TB)^$PQR$C!ZAM,`TPD<$@QR$V-A`"AZ]EN2(GP2,'@!4@)PD0!PDF)R$C!
MX1Y)P>@"20G(2(G108/@_TC!Z1M,B<!(,?A(`WPD>$@Q\$V-C`&AZ]EN2(G0
M2,'@!4@)P40!R4F)\4C!YAY)P>D"20GQ2(G.08/A_TC![AM,B<A,,<!,`X0D
M@````$@QT$B-O`>AZ]EN2(G(2,'@!4@)Q@'^2(G72,'B'DC![P)("==(B?*#
MY_](B?A,,<A(P>H;3`.,)(@```!(,<A-C80`H>O9;DB)\$C!X`5("<)$`<))
MB<A(P>$>2<'H`DD)R$B)T4&#X/](P>D;3(G`2#'X2`.\))````!(,?!-C8P!
MH>O9;DB)T$C!X`5("<%$`<E)B?%(P>8>2<'I`DD)\4B)SD&#X?](P>X;3(G(
M3#'`3`.$))@```!(,=!(C;P'H>O9;DB)R$C!X`5("<8!_DB)UTC!XAY(P>\"
M2`G72(GR@^?_2(GX3#'(2,'J&TP#C"2@````2#'(38V$`*'KV6Y(B?!(P>`%
M2`G"1`'"28G(2,'A'DG!Z`))B=))"<A(B=%)P>H"08/@_TC!Z1M,B<!(,?A(
M`[PDJ````$@Q\$V-C`&AZ]EN2(G02,'@!4@)P40!R4F)\4C!YAY)P>D"28G,
M20GQ2(G.08/A_TC![AM,B<A,,<!,`X0DL````$@QT$C!XAY(C;P'H>O9;DD)
MTDB)R$&#XO](P>`%2`G&3(G0`?Y,,<A)P>P"2#'(2,'A'DB)\DV-A`"AZ]EN
M20G,2(GP08/D_TP#C"2X````2,'@!4C!ZAM(B?-(BXPDR````$@)PDR)X$C!
MZP),,=!$`<),`Y0DP````$@Q\$C!YAY(B==-C8P!H>O9;D@)\TB)T(/C_TC!
MX`5(P>\;2`G'2(G828G33#'@1`'/2<'K`D@QT$C!XAY)B?A-C90"H>O9;DD)
MTTB)^$&#X_](P>`%2<'H&TD)P$P!Z4R)V$4!T$R)VDP!X4@)V$@AVDR)QD@A
M^$F)^4C![AM("=!(P><>2<'I`D@!P4R)P$D)^4C!X`5!@^'_38G"2`G&3(G(
M3(G*`<Y(BXPDT````$P)V$PAVDPAP$B)]T@)T$C![QM)P>`>3`'I2<'J`D&\
MUL%BRD@!V4T)PD@!P4B)\$&#XO](P>`%3(G22`G'3(G0`<](BXPDV````$P)
MR$@A\$F)^$P!Z4P!V4PARDF)\T@)T$C!YAY)P>@;2`'!2(GX2<'K`DC!X`5)
M"?-)"<!!@^/_00'(2(N,).````!,B=A,"=!,B=I,B<9,(=)((?A(P>X;3`'I
M2`G03`')28GY2,'G'D@!P4R)P$G!Z0)(P>`%20GY2`G&08/A_P'.2(N,).@`
M``!,B<A,"=A,B<I(B?=,(=I,(<!,`>E("=!,`=%-B<)(`<%(B?!(P>\;2,'@
M!4G!X!Y)P>H"2`G'30G"`<]!@^+_2(N,)/````!,B=!,B=))B?A,"<A,(<I)
MP>@;3`'I2"'P2`G03`'928GS2`'!2(GX2,'F'DC!X`5)P>L"20G`20GS00'(
M08/C_TB+C"3X````3(G83(G:3(G&3`G03"'22,'N&TP!Z4@A^$@)T$P!R4F)
M^4@!P4R)P$C!X`5("<8!SDC!YQY)P>D"20GY2(N,)``!``!(B?=!@^'_2,'O
M&TR)R$R)RDP)V$PAVDP!Z4PAP$P!T4V)PD@)T$G!X!Y)P>H"2`'!2(GP30G"
M2,'@!4&#XO]("<=,B=!,B=(!STB+C"0(`0``3`G(3"'*2"'P28GX2`G02<'H
M&TP!Z4P!V4F)\TC!YAY(`<%(B?A)P>L"2,'@!4D)P$$!R$D)\TB+C"00`0``
M08/C_TR)QDR)V$R)VDC![AM,"=!,(=),`>E((?A,`<E)B?E("=!(P><>2<'I
M`D@!P4R)P$D)^4C!X`5!@^'_2`G&3(G(3(G*`<Y(BXPD&`$``$P)V$PAVDPA
MP$B)]T@)T$C![QM,`>E,`=%-B<))P>`>2`'!2(GP2<'J`DC!X`5-"<)("<=!
M@^+_`<](BXPD(`$``$R)T$R)TDF)^$P!Z4P!V4P)R$PARD@A\$F)\TG!Z!M(
M"=!(P>8>2<'K`D@!P4B)^$D)\TC!X`5!@^/_20G`3(G83(G:00'(2(N,)"@!
M``!,"=!,(=)((?A,B<9("=!(P>X;3`'I3`')28GY2,'G'D@!P4R)P$G!Z0)(
MP>`%20GY2`G&08/A_P'.2(N,)#`!``!,B<A,"=A,B<I(B?=,(<!,`>E,`=%,
M(=I-B<)("=!)P>`>2,'O&T@!P4B)\$G!Z@)(P>`%30G"2`G'08/B_P'/2(N,
M)#@!``!,B=!,"<A,B=))B?A,(<I((?!)P>@;3`'I2`G03`'928GS2,'F'D@!
MP4B)^$G!ZP)(P>`%20GS20G`08/C_T$!R$B+C"1``0``3(G83`G03(G:3(G&
M3"'22"'X3`'I2`G03`')28GY2`'!3(G`2,'N&TC!X`5(P><>2<'I`D@)QDD)
M^0'.08/A_TB+C"1(`0``3(G(3(G*2(GW3`G83"':2,'O&TP!Z4PAP$@)T$P!
MT4V)PD@!P4B)\$G!X!Y(P>`%2<'J`D@)QTT)P@'/08/B_TB+C"10`0``3(G0
M3(G228GX3`G(3"'*2<'H&TP!Z4@A\$@)T$P!V4F)\T@!P4B)^$C!X`5)"<!!
M`<A(P>8>2<'K`DD)\TB+C"18`0``3(G&08/C_TC![AM,B=A,B=I,`>E,"=!,
M(=),`<E((?A)B?E("=!(P><>2<'I`D@!P4D)^4R)P$&#X?],`ZPD8`$``$C!
MX`5("<9,B<A,B<I,"=A,(=H!SDPAP$B)]T@)T$T!U4C![QM)`<5(B?!-B<)(
MP>`%2<'@'DG!Z@)("<=(BY0D:`$``$0![TT)PDF)\$&#XO](B?E)P>@"3(G0
M3`'B2,'I&TPQR$P!VD@Q\$C!YAY(`<)(B?A)"?!(P>`%08/@_T@)P4R)P`'1
M2(N4)'`!``!,,=!(,?A(B<Y(P>X;3`'B3`'*28GY2,'G'D@!PDB)R$G!Z0)(
MP>`%20GY2`G&08/A_P'62(N4)'@!``!,B<A,,<!(B?=(,<A,`>),`=))B<I(
M`<)(B?!(P>\;2,'@!4C!X1Y)P>H"2`G'20G*`==(BY0D@`$``$&#XO],B=!(
MB?E,,<A(P>D;3`'B2#'P3`'"28GP2,'F'D@!PDB)^$G!Z`)(P>`%20GP2`G!
M08/@_P'12(N4)(@!``!,B<!,,=!(B<Y(,?A(P>X;3`'B3`'*28GY2,'G'D@!
MPDB)R$G!Z0)(P>`%20GY2`G&`=9(BY0DD`$``$&#X?],B<A(B?=,,<!(P>\;
M3`'B2#'(3`'228G*2,'A'D@!PDB)\$G!Z@)(P>`%20G*2`G'08/B_P'72(N4
M))@!``!,B=!,,<A(B?E(,?!(P>D;3`'B3`'"28GP2,'F'D@!PDB)^$G!Z`)(
MP>`%20GP2`G!08/@_P'12(N4)*`!``!,B<!,,=!(B<Y(,?A(P>X;3`'B3`'*
M28GY2`'"2(G(2,'@!4C!YQY)P>D"2`G&20GY`=9(BY0DJ`$``$&#X?],B<A(
MB?=,,<!(P>\;3`'B2#'(3`'228G*2,'A'D@!PDB)\$G!Z@)(P>`%20G*2`G'
M08/B_P'72(N4)+`!``!,B=!,,<A(B?E(,?!(P>D;3`'B3`'"28GP2,'F'D@!
MPDB)^$G!Z`)(P>`%20GP2`G!08/@_P'12(N4)+@!``!,B<!(B<Y,`>),,=!(
MP>X;2#'X3`'*28GY2`'"2(G(2,'G'DC!X`5)P>D"2`G&20GY`=9(BY0DP`$`
M`$&#X?],B<A(B?=,,<!(P>\;3`'B2#'(3`'228G*2,'A'D@!PDB)\$G!Z@)(
MP>`%20G*2`G'08/B_P'72(N4),@!``!,B=!,,<A(B?E(,?!(P>D;3`'B3`'"
M28GP2`'"2(GX2,'@!4@)P4C!YAY)P>@"`=%)"?!(BY0DT`$``$&#X/](B<Y,
MB<!(P>X;3`'B3#'02#'X3`'*28GY2`'"2(G(2,'G'DC!X`5)P>D"2`G&20GY
M`=9(BY0DV`$``$&#X?],B<A(B?=)B?-,,<!(P>\;3`'B2#'(3`'228G*2,'A
M'D@!PDB)\$G!Z@)(P>`%20G*2`G'08/B_P'72(N4).`!``!,B=!(B?E(B?M,
M`>),`<),,<A(P>D;2#'P2<'K`DC!YAY(`<)(B?A)"?-(P>`%08/C_TC!ZP)(
M"<%,B=@!T4B+E"3H`0``3#'02#'X28G(2,'G'DG!Z!M("?M,`>*#X_],`<I)
MB<E(`<)(B<A(P>`%20G`2(G800'02(N4)/`!``!,,=A(,<A,B<=,B<9(P>\;
M3`'B3`'22`'"3(G`2,'@!4@)QP'72,'A'DG!Z0))"<E(BY0D^`$``$C![@)!
M@^'_2(GY3(G(2,'I&TP!XD@QV$P#I"0``@``3#'`3`':2<'@'D@!PDP)QDB)
M^$C!X`6#YO]("<%(B?!)`=Q,,<@!T4@Q^$B)RDD!Q$B)R$C!X@5(P>@;2`G0
M1`'@1`'P2(E%`$B)^$C!YQY(P>@"`TT(2`GX`T40`W481`--($B)30A(B440
M2(EU&$R)32!(@<0(`@``6UU!7$%=05[#3(ED).!,B7PD^$F)_$B)7"302(EL
M)-A)B?=,B6PDZ$R)="3P2(/L.$B%_W4E,<!(BUPD"$B+;"003(MD)!A,BVPD
M($R+="0H3(M\)#!(@\0XPTR+-5>1$`!-A?9TSP^V!X3`=00QP.L7/#U(B?IT
M]4B#P@$/M@*$P'5%B=!$*>!)BRY(A>UTI4QCZ$R)\V:03(GJ3(GF2(GOZ*[D
M__^%P'4*28U$+0"`.#UT&DB+:PA(@\,(2(7M==?I;____V:0/#UUK.NU3"GS
M2(/``4C!^P-!B1_I5O___V9F9I!F9I!54TB)^TB#[!A(C6PD%&:0,<!(B>Y(
MB=_H`____TB%P'0F2&-$)!1(C13%`````$@#%9J0$`!(@\((2(L"2(7`2(E"
M^'7PZ\A(@\086UW#D$B#[!@QP$B-="04Z,#^__](@\08PV9F9I!F9F:09F:0
M2(/L"(,]>8,0`/]T"XL%<8,0`$B#Q`C#,<"_'51``.B\____2(7`=`</M@"$
MP'43,<")!4R#$`"+!4:#$`!(@\0(PSPP#Y7`#[;`Z^5F9I!(@^P(O______H
M_N/__S'VO[`X0`!(@\0(Z2[F__]FD$B+!4F+$`!3,?:_OU5``$B+2`A(BP5V
MBQ``#[=0(`^V!4.+$`!F@>+_`8/@?\'B!PG"9HE1`DB+!1.+$`!(BU@(Z.;C
M__](B4,H2(L%_XH0`$B+4`A(BP5$BQ``2(E",$B+!>F*$``QTDB+2`A(BP7,
MBA``2(7`=`=(BY"H````2(E1.$B+!<6*$`!(BT`(2,=`0`````!(BP6RBA``
M2(M`"$C'0"``````2(L%GXH0`$B+4`A(BP7<BA``2(E"2%O#9F9FD&9F9I!F
M9I!F9I!,B60DZ$B)7"3828G\2(EL).!,B6PD\$R)="3X2('LJ````$B%_W0%
M@#\`=3-(BYPD@````$B+K"2(````3(ND))````!,BZPDF````$R+M"2@````
M2('$J````,-F9I#HA^/__TB%P$B)Q73`9F:02(GOZ+3D__](A<`/A*$```!(
MC5@(ORA40`"Y`@```/Q(B=[SIG39OR=40`"Y`P```$B)WO.F=,A,B>?H_.3_
M_TB)WTF)Q>CQY/__08U$!0)(8_CH-.3__TB)V4B)QTF)Q4R)XKXJ5$``,<#H
M_.3__TB)YDR)[^CQXO__@\`!=!$/MT0D""4`\```/0!```!T-DR)[^B3XO__
M3(GOZ"OD__](B>_H$^3__TB%P`^%7____TB)[^B2Y/__3(GGZ.KB___I]O[_
M_TR)[^C!_O__D.O'9F9FD&9F9I!F9I!F9I!32(G[2(/$@$B)YNA,X?__A<!U
M&`^W1"0()0#P```]`$```'0//0"@``!T"$B#[(`QP%O#2(G?O@(```#H.^+_
M_X7`#Y3`2(/L@%L/ML##D$%7,<!!5DF)_D%505152(GU4TB#[!B`/CT/E,!(
M`<5(B>_HY>/__TB-="0408G'3(GW,<#HE_O__TB%P$B)PW0W2(G'Z,/C__]$
MB?I(.=`/@KP````/MD4`2(/%`8@#2(/#`83`=>Y(@\08,<!;74%<05U!7D%?
MPTB+/0&-$`!%,>2X$````$B#/P!T'TB)^DB+0@A!@\0!2(/""$B%P'7O08U$
M)`)(F$C!X`.+%8Z($`"%T@^%$`$``$B)Q\<%>8@0``$```#HD.+__TB%P$F)
MQ0^$&0$``$ECQ$B+-9Z,$`!,B>](C1S%`````$B)VN@GXO__3(DMA(P0`$B+
M!7V,$`!(QT0#"`````!$B60D%$$/MA9,B?"$T@^%B````(M<)!1%*?=!C7P'
M`DC!XP-(`QU)C!``Z"#B__](A<!(B0,/A*D```"+5"042(L%+8P0`$B+%-!!
M#[8&A,"(`G0E/#UT(4R)]^L.9F:09F:02(/'`3P]=`X/MD<!2(/"`83`B`)U
MZL8"/69F9I!F9I`/MD4`2(/%`8A"`4B#P@&$P'7MZ;_^__^`^CT/A&____](
M@\`!#[8(A,D/A&#___^`^3UU[.E6____2(G&9F:0Z,??__](A<!(B06ABQ``
M=!!)8\1(C1S%`````.D+____2(/$&+C_____6UU!7$%=05Y!7\-F9F:09F9F
MD&9FD$%7059)B?Y!54%40;PZ5$``55-(@^Q(3(L]ZA@``$F)Y4C'!"0Z5$``
M2,=$)`@P5$``2,=$)!`]5$``2,=$)!@S5$``2,=$)"`X5$``2,=$)"A*5$``
M2,=$)#``````ZQY,B?9,B><QP.B"_?__38ME"$F#Q0A-A>0/A(D````QP$R)
MY^AG^O__2(7`2(G%=-"`.`!TRTR)]DB)Q^C[W___2(7`=<A,B??H3N'__TR)
M_TB)P^A#X?__2(U<`P%(B>_H-N'__TB-/`/H?>#__TF)Z$B)QTB)PTR)^4R)
M\KYD54``,<#H0N'__TR)YS'`2(G>Z/G\__]-BV4(28/%"$V%Y`^%=____TB#
MQ$A;74%<05U!7D%?PV9FD&9FD&9FD$B#[#B_551``$B+!5"%$`!(B40D*#'`
M2(L%FA<``$B)!"1(BP67%P``2(E$)`A(BP63%P``2(E$)!!(BP6/%P``2(E$
M)!@/MP6+%P``9HE$)"`QP.@G^?__,<"_7E1``.@;^?__,<"_9E1``.@/^?__
M,<"_;U1``.@#^?__,<"_=E1``.CW^/__,<"_AE1``.CK^/__,<"_DE1``.C?
M^/__,<"_'51``.C3^/__,<"_FU1``.C'^/__,<"_I51``.B[^/__,<"_KU1`
M`.BO^/__,<"_O%1``.BC^/__,<"_Q51``.B7^/__,<"_T%1``.C;^/__2(7`
M=`](B<:_FU1``#'`Z,?[__\QP+_A5$``Z+OX__](A<!T#TB)QK_S5$``,<#H
MI_O__S'`O_Y40`#HF_C__TB%P'0V2(G&OY)40``QP.B'^___,<"^*E5``+]V
M5$``Z';[__](BT0D*$@S!?J#$`!U44B#Q#C#9F:0,<"_#E5``.A4^/__2(7`
M=!%(B<:_'51``#'`Z$#[___KMTB-="01OQ]50`"Y"@```/SSIG6C2(UT)!N_
M'51``#'`Z!G[___KD.C>WO__9I!(@^P(Z+/>__^)Q^C\W?__,=)(A<!T`TB+
M$$B)T$B#Q`C#9F9FD&9F9I!F9I!F9I!54TB)^TB#[`A(A?]T"`^V+T"$[740
M2(/$"+\H5$``6UWIYMO__^C!WO__2`'82(U0_T@YTP^#G@```$B+/:X5```/
MMD#_#[8W0#CP=`GK*@^V"CC!=69(@^H!2#G39I!R[D@YVG4I0#HO=*I(@\0(
M6UWIE=O__P^V`D`XQG3C2(/J`4@YTW+OZ]AF9I!F9I!(@^H!2#G3<PD/M@(Z
M!V:0=.Y(*=HQR4B-0@)(/0`$``!V#DB#Q`A(B<A;7<.)R.NY2(/"`4B)WK^`
MQ%``Z/K;__^Y@,10`.O:2(L]$!4``.N`9F9FD&9F9I!F9I!F9I!(B5PD\$B)
M;"3X2(/L&$B)^^CZ_O__2(G'Z'+?__](B<4QP.CH]O__A<!T"DB%VW0%@#L`
M=0](BUPD"$B+;"002(/$&,.^+%5``$B)[^A*W/__2#G%==](B=](BVPD$$B+
M7"0(2(/$&.GC]___9F:04TB#["")?"0<2(ET)!!(C7PD'$B)5"0(2(UT)!!(
MC50D".AEV___@#TJ@A````^$*0$``(M$)!R`#1J"$``#@\`%2&/(2(7)#XA*
M`0``\D@/*L'R#U@%=14``&8/+@5U%0``#X=,`0``2(T\S0````#H=MW__TB+
M="002(G!2(D%<X80`$R-2?A(BP9(QT$(,55``$C'01`@8%``2,=!&#150`!(
MB0%$BT0D',<%.H80``0```!!@_@!?BE,C4GXOP$```"Z"````&9FD&9FD$B+
M!!:#QP%(B40*&$B#P@A!.?A_ZT&-0`2^8%-``$4QP$B82<<$P0````"+5"0<
M2(L]VH40`(/"`^@>VO__A<")PW1Q2(L]Q840`.A,V___,<"_AE1``.A4]?__
M2(7`=!E(BSVHA1``Z+_<___HBMS__XG82(/$(%O#2(L]EX40`$B%_W1PZ#7^
M___KU&9FD.B'V___2(7`2(G'2(D%;H40`'1TZ'/9___&!8"`$```Z:_^__](
MBSU4A1``Z%O:__^)P^E\____2(G(2(G*2-'H@^(!2`G0\D@/*L#R#UC`Z9[^
M__^^(,10`+^V54``,<#HAMC__[^25$``Z+#T__](A<!(B<=(B04+A1``#X5S
M____Z4G___]`MP'HS-K__T%7059!54%428G\OY)40`!54TB)\TB![*@$``!(
MBP7]?Q``2(F$))@$```QP.A>]/__2(LM9Q(``$R)YTF)Q4B)[NCUV?__2(7`
M=#E,B>:_KU1``#'`Z#7W__](BY0DF`0``$@S%;9_$`!,B>`/A30!``!(@<2H
M!```6UU!7$%=05Y!7\-,B>?H#]O__TR+/102``!(B=]!B<9,B?[H"MG__TB%
MP$B)PW2B08/&`42)="0,3(VT))````!F9I!FD(`[`+@H5$``2`]$V$V%[70/
M2(G>3(GOZ'#9__^%P'1^2(G?Z+3:__^)P4B8#[9$`_\Z10!U'8U!_TB82(T4
M&)`/MD+_Q@(`@^D!2(/J`3I%`'3MBT0D#`'(/?\#```/CRC___]-B>!(B>E(
MB=J^9%5``$R)]S'`Z)#:__](C70D$$R)]^B#V/__A<!U$0^W1"08)0#P```]
M`(```'0;,?],B?[H1-C__TB%P$B)PP^%3/___^G3_O__O@$```!,B??H-MC_
M_X7`==1,B?:_KU1``.CY]?__3(GWZ!W7__])B<3IM/[__^BPV?__9F9FD$%7
M28G_OY)40`!!5D%505154TB![.B!``!(BP50?A``2(F$)-B!```QP$C'A"30
M````-U5``$C'A"38````/%5``$C'A"3@`````````.B-\O__2(7`2(G#=`F`
M.``/A9H"```QP$B-G"30````Z%WZ__](A<!)B<4/A-(!``!!#[9%`(3`=#I,
MB>EF9I!FD`^^P(7`>!P[!2M^$`!]%$ACT$B+!2=^$`#W1-!```4``'4#Q@%?
M#[9!`4B#P0&$P'7.2(VL)*````"_\U1``$C'A"2@````\U1``$C'A"2H````
M[%1``$C'A"2P````3%5``$C'A"2X````"55``$C'A"3`````5%5``$C'A"3(
M`````````.L89F9FD&9FD$B+?0A(@\4(2(7_#X1/`0``,<#HJ/'__TB%P$B)
MPW3@@#@`=-M(B<?H0_3__X7`D'3.2(G?Z++5__](A<!)B<0/A!T!``!,B>?H
M?MC__TR)[TB)P^ASV/__C80#!`0``$ACZ$B)[^BQU___2(L57@\``$B)QTF)
MQDV)Z4&X+%5``+YB54``,<!(B=%(B50D$$R)XNADV/__OL`!``!,B??H9]?_
M_X/``0^$2`$``$B-="0@3(GWZ!'5__^%P'45#[=$)"@E`/```#T`0```#X1:
M`0``28L72(L]^GP0`$R)\;Z`5D``,<`Q[>BMU/__2(N4)-B!``!(,Q52?!``
M2(GH#X5Y`@``2('$Z($``%M=05Q!74%>05_#2(G'Z,O4__])B<5(@\,(387M
M#X4N_O__2(L[2(7_#X0X`@``,<#H?/#__TB%P'3;@#@`=<M(@\,(387M=-KI
M`_[__V9F9I!%,>2`/8X-````2,>$)/````!854``NUA50`!(QX0D^````"A4
M0`!(QX0D``$```````!(C:PD\````'4HZ:3^__]-A>0/A9O^__](BUT(2(7;
M#X2._O__2(/%"(`[``^$@?[__TB)W^BC\O__A<!TT4B)W^@3U/__28G$Z\1(
MB<?HZO3__TB)W^C^T___2(G%Z?G^___H4=7__X,X$6:0#X2H_O__Z$'5__])
MBQ=$BP!,B?%(BSV]>Q``OD!60``QP#'MZ'/3___IP?[__XM<)"SH-=;__SG#
M#X65_O__#[=$)"@E_P$``#W``0``#X6`_O__2(GOZ,#5__^_,U1``$B)Q3'`
MZ%7O__](A<!(B<</A`X!``#H<-/__TF+/TB)QNBI^O__2(7`28G$#X3R````
M3(GGZ#'6__^#^`-!B<`/CV@%```QP.@R[___A<!U%C'V3(GGZ!#5__^%P(E$
M)!P/A<4```"^*E5``+\=5$``,<#HY_'__^C.U?__2(M,)!!!B<!!N;]50`!,
MB?*^B55``$B)[S'`,=OH_-7__^L]Z$74__^#.!%F9I!F9I!U/^B5U?__2(M,
M)!"#PP%!B<!!B=E,B?*^EU5``$B)[S'`2,<$)+]50`#HO=7__[[``0``2(GO
MZ,#4__^#P`%TL4R)]^@#U?__2(GNOY)40``QP.A8\?__2(GOZ&#S___I>OW_
M_T&]155``.DB_/__Z`?5__]-BR?I!O___[H"````2,?&[O___XG'Z+S3__^+
M?"0<2(VT)!`!``"Z!@```.@VU?__@+PD$`$```!U#H"\)!$!``!##X38!```
MBWPD'#'V,=),C:0D$($``.AYT___OXFKS>^^_MRZF+GPX=+#2,>$)!"!```!
M(T5G2(F\)!B!``!)@\0X2(FT)""!``!(QX0D*($``'94,A!(B8PD,($``$C'
MA"0X@0```````$C'A"1`@0```````,>$)(B!````````BWPD'$B-M"00`0``
MN@"```#HC=3__X7`08G%#XXZ`0``2(N,)#B!``!)8]5(BX0D0($``$B-G"00
M`0``C3312#G.2(FT)#B!``!(@]``2,'J'4B)A"1`@0``2`&4)$"!``"+E"2(
M@0``A=)T:>F%````9F:09I!(BP-(C;PD$($``$&#[4!(B80D2($``$B+0PA)
MB40D"$B+0Q!)B40D$$B+0QA)B40D&$B+0R!)B40D($B+0RA)B40D*$B+0S!)
MB40D,$B+0SA(@\-`28E$)#CH@=7__T&#_3]_FTECU4B)WDR)Y^@)T___1(FL
M)(B!``#I"?___[A`````2&/Z2(VT)!`!```IT$F-/#Q!.<6)PT$/3MU,8_M,
MB?KHTM+__XG8`X0DB($``(/X0(F$)(B!```/A<;^__](C8PD$`$``$$IW4B-
MO"00@0``28T<#^@!U?__Z7O___^+?"0<Z._1__](BYPD.($``$R+I"1`@0``
M2(G82,'H`X/@/TACT(/``8/X.,:$%$B!``"`#XZG`@``2&/XND`````Q]BG"
M2(V\/$B!``!(8]+H(M'__TB-O"00@0``Z)G4__](C;PD$($``+D'````,<#\
M2(/'./-(JTR)X$B-O"00@0``1(BD)(.!``!(P>@8B)PDAX$``$R-O"20@0``
MB(0D@($``$R)X$R-K"3`@0``2,'H$(B$)(&!``!,B>!-B?Q(P>@(B(0D@H$`
M`$B)V$C!Z!B(A"2$@0``2(G82,'H$(B$)(6!``!(B=@QVTC!Z`B(A"2&@0``
MZ/W3__](BY0D$($``$B)T(B4),.!``!(P>@8B(0DP($``$B)T$C!Z!"(A"3!
M@0``2(G02(N4)!B!``!(P>@(B(0DPH$``$B)T(B4),>!``!(P>@8B(0DQ($`
M`$B)T$C!Z!"(A"3%@0``2(G02(N4)""!``!(P>@(B(0DQH$``$B)T(B4),N!
M``!(P>@8B(0DR($``$B)T$C!Z!"(A"3)@0``2(G02(N4)"B!``!(P>@(B(0D
MRH$``$B)T(B4),^!``!(P>@8B(0DS($``$B)T$C!Z!"(A"3-@0``2(G02(N4
M)#"!``!(P>@(B(0DSH$``$B)T(B4)-.!``!(P>@8B(0DT($``$B)T$C!Z!"(
MA"31@0``2(G02,'H"(B$)-*!``!"#[84*TR)YS'`OH150`!(@\,!28/$`N@@
MT?__2(/[%'7>QH0DN($```!!N;]50`!-B?A(BTPD$$R)\KYU54``2(GO,<#H
M\M#__^E"^___2)B_:U5``$F-=`3\N`4```#\2(G!\Z8/A7OZ__]!@_@$=!E!
MC4#\2(M4)!!(F$$/MD0$_SH"#X5<^O__28M?"$B%VP^$3_K__TB)W^ALT/__
M2(/X`P^&/?K__TB-=`/\OW!50`"Y!0```/SSIDP/1./I(OK__[HX````2&/X
M,?8IPDB-O#Q(@0``2&/2Z'O.___I>/W__X"\)!(!``!!#X4:^___@+PD$P$`
M`$,/A0S[__^`O"04`0``2`^%_OK__X"\)!4!``!%#X7P^O__BWPD'+H"````
M2,?&QO___^AISO__BWPD'$B-M"00`0``NBD```#HX\___TR-A"00`0``0;F_
M54``Z=?^__]F9F:02(E<).A(B6PD\$R)9"3X2('L.`@``$B-G"00!```2(L%
M"W00`$B)A"08"```,<#H6,___[FH54``B<*^K55``#'`2(G?Z)+/__^%P'DV
M,>U(BY0D&`@``$@S%=%S$`!(B>AU8$B+G"0@"```2(NL)"@(``!,BZ0D,`@`
M`$B!Q#@(``##2(G?N@`$``!(B>;H:,___X7`B<-XM(UX`4AC_^A7SO__2(7`
M=*1(8]M(B<5(B>9(B=I(B<?H7L[__\8$*P#KC.BCSO__9F9FD&9FD.DK____
M9F9FD&9F9I!F9I!!5#'`OW940`#&!9QS$``!55/HJ>?__TB%P'0)@#@Q#X2C
M`0``,<#HQ.W__[H+````O@$```"_N55``.BLS?__2(7`#X2`````,>V#/=YW
M$``!2(M`$$R+8"A^7+L(````ZRI(BW<02(L%RG<0`$B+/!CH!<W__X7`=3V#
MQ0%(@\,(C44!.06E=Q``?BLQTHGN3(GGZ"/.__](A<!T&DB+./9'#01UO#'V
MN@(```#H^<K__TB)QNNOBQ5R=Q``C4+_.>@/A-(```"Z!````+X!````O[Y5
M0`#H#\W__TB%P$B)PW0B2(M`$+[`54``2(LXZ);+__](BT,02(LX]D<.0`^%
MU````+H$````O@$```"_SE1``.C1S/__2(7`2(G%="<QP+^O5$``Z)'F__](
MA<!(B<(/A-$```!(BT402(G62(LXZ$++__\QP+^25$``Q@54<A```$C'!>5Q
M$```````Z%CF__](A<!(B06V=A``=':^P`$``$B)Q^B+S/__A<!T$8/X$70,
M@_C_9F:0#X6?````6UU!7,.#Z@%FD`^.(____[L!````9F:09I!,B>>#PP'H
M0<K__SD=;W80`'_MZ0'___^`>`$`9F9FD`^$5O[__^E*_O__9F:09I#H)\K_
M_^D=____2(L]1W80`.CJ\O__2(7`2(D%*'80`'5MO]A60`#H@,G__^C?_?__
M2(7`2(G#=#M(BT402(G>2(LXZ&3*__](B=_H+,S__^D5____B<%(BP7Z=1``
M2(L5XW40`+\H5T``2(LP,<#H.,G__TB+51!(BP79=1``2(LZ2(LPZ"+*___I
MV_[__TB+11!(BQV^=1``2(LX]D<-!'0Z2(M_$$B)WN@MR?__B<-(BT402(LX
M]D<-!'0P2(M'$$B)PDB+!8QU$`")V;\`5T``2(LP,<#HS\C__[H"````,?;H
MX\C__TB)Q^NYN@(````Q]NC2R/__Z\9F9F:0NL550`"^[!U``+_/54``Z:C)
M__]F9F:09F9FD&9F9I!(@^P(Z-?___^YOU5``$4QP+Y@4$``2(G*O^M50`!(
M@\0(Z?7(__^0D)"0D)"0D)!(BP7I;1``4TB#^/]T%3';_]!(BX-XP5``2(/K
M"$B#^/]U[5O#D)"02(/L".B/S/__2(/$",,``"1&<F5E0E-$.B!S<F,O;&EB
M+V-S=2]A;60V-"]C<G1I+E,L=B`Q+C<N,S`N,2XT+C$@,C`Q,"\P-B\Q-"`P
M,CHP.3HP-B!K96YS;6ET:"!%>'`@)`!005)?0TQ%04X`+BX`)7,O)7,`3$E"
M4$%42`!$64Q$7TQ)0E)!4EE?4$%42`!32$Q)0E]0051(`%!%4DPU3$E"`%!%
M4DQ,24(`4$523#5/4%0`4$523$E/`%!!4E])3DE424%,25I%1`!005)?4U!!
M5TY%1`!005)?5$5-4`!005)?1$5"54<`4$%27T-!0TA%`%!!4E]04D]'3D%-
M10!005)?05)'0P!005)?05)'5E\P`%!!4E]'3$]"04Q?1$5"54<`4$%27T=,
M3T)!3%]435!$25(`4$%27U1-4$1)4@!005)?1TQ/0D%,7U1%35``4$%27T=,
M3T)!3%]#3$5!3@!005)?0TQ%04X]`#$`<&%R+0`M90`M+0!54T52`%5315).
M04U%`%-94U1%30!414U01$E2`%1-4``O=F%R+W1M<"\`)7,E<R5S)7,`<&%R
M;``N<&%R`"5S)7-C86-H92TE<R5S`"4P,G@`)7,E<W1E;7`M)74E<P`E<R5S
M=&5M<"TE=2TE=25S`&9I;&4`+W!R;V,O)6DO)7,`05)'5@`8`'!E<FP`<&5R
M;'AS:2YC`$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E<@!);G1E<FYA;',Z
M.E!!4CHZ0D]/5``Z`````````%]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@
M("`@("`@``````````!@54````````!60```````)7,Z(&-R96%T:6]N(&]F
M('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@``
M`````"5S.B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!I<R!U;G-A9F4@*'!L
M96%S92!R96UO=F4@:70@86YD(')E=')Y('EO=7(@;W!E<F%T:6]N*0H`````
M``!5;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R>0``````````)7,Z
M(&5X96-U=&EO;B!O9B`E<R!F86EL960@*&5R<FYO/25I*0H``"5S.B!C<F5A
M=&EO;B!O9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL960@
M*&5R<FYO/25I*0H`````````````````````````````P$,D1G)E94)31#H@
M<W)C+VQI8B]C<W4O86UD-C0O8W)T;BY3+'8@,2XV+C,P+C$N-"XQ(#(P,3`O
M,#8O,30@,#(Z,#DZ,#8@:V5N<VUI=&@@17AP("0``````1O__^QC$```````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````OU5``````````````````)C!4``````````````````C(2]U<W(O
M8FEN+W!E<FP*979A;"`G97AE8R`O=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K
M(B1`(GTG"B`@("!I9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE
M;&P*"G!A8VMA9V4@7U]P87)?<&P["@HC("TM+2!4:&ES('-C<FEP="!M=7-T
M(&YO="!U<V4@86YY(&UO9'5L97,@870@8V]M<&EL92!T:6UE("TM+0HC('5S
M92!S=')I8W0["@HC;&EN92`Q-3@*"FUY("@D<&%R7W1E;7`L("1P<F]G;F%M
M92P@0'1M<&9I;&4I.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]*2!["B`@
M("!R97%U:7)E($9I;&4Z.E1E;7`["B`@("!R97%U:7)E($9I;&4Z.D)A<V5N
M86UE.PH@("`@<F5Q=6ER92!&:6QE.CI3<&5C.PH@("`@;7D@)'1O<&1I<B`]
M($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D["B`@("!O=71S
M*'%Q>U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B?2D["B`@("!&:6QE
M.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI
M;FL@?2P@)'!A<E]T96UP*3L*("`@(')M9&ER("1P87)?=&5M<#L*("`@(",@
M1&]N)W0@<F5M;W9E('1O<&1I<B!B96-A=7-E('1H:7,@8V%U<V5S(&$@<F%C
M92!W:71H(&]T:&5R(&%P<',*("`@(",@=&AA="!A<F4@=')Y:6YG('1O('-T
M87)T+@H*("`@(&EF("@M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R
M)RD@>PH@("`@("`@(",@4V]M971H:6YG('=E;G0@=W)O;F<@=6YL:6YK:6YG
M('1H92!T96UP;W)A<GD@9&ER96-T;W)Y+B`@5&AI<PH@("`@("`@(",@='EP
M:6-A;&QY(&AA<'!E;G,@;VX@<&QA=&9O<FUS('1H870@9&ES86QL;W<@=6YL
M:6YK:6YG('-H87)E9`H@("`@("`@(",@;&EB<F%R:65S(&%N9"!E>&5C=71A
M8FQE<R!T:&%T(&%R92!I;B!U<V4N(%5N;&EN:R!W:71H(&$@8F%C:V=R;W5N
M9`H@("`@("`@(",@<VAE;&P@8V]M;6%N9"!S;R!T:&4@9FEL97,@87)E(&YO
M(&QO;F=E<B!I;B!U<V4@8GD@=&AI<R!P<F]C97-S+@H@("`@("`@(",@1&]N
M)W0@9&\@86YY=&AI;F<@;VX@5VEN9&]W<R!B96-A=7-E(&]U<B!P87)E;G0@
M<')O8V5S<R!W:6QL"B`@("`@("`@(R!T86ME(&-A<F4@;V8@8VQE86YI;F<@
M=&AI;F=S('5P+@H*("`@("`@("!M>2`D=&UP(#T@;F5W($9I;&4Z.E1E;7`H
M"B`@("`@("`@("`@(%1%35!,051%(#T^("=T;7!86%A86"<L"B`@("`@("`@
M("`@($1)4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*
M("`@("`@("`@("`@4U5&1DE8(#T^("<N8VUD)RP*("`@("`@("`@("`@54Y,
M24Y+(#T^(#`L"B`@("`@("`@*3L*"B`@("`@("`@<')I;G0@)'1M<"`B(R$O
M8FEN+W-H"G@],3L@=VAI;&4@6R!<)'@@+6QT(#$P(%T[(&1O"B`@(')M("UR
M9B`G)'!A<E]T96UP)PH@("!I9B!;(%PA("UD("<D<&%R7W1E;7`G(%T[('1H
M96X*("`@("`@(&)R96%K"B`@(&9I"B`@('-L965P(#$*("`@>#U@97AP<B!<
M)'@@*R`Q8`ID;VYE"G)M("<B("X@)'1M<"T^9FEL96YA;64@+B`B)PHB.PH@
M("`@("`@("`@("!C:&UO9"`P-S`P+"1T;7`M/F9I;&5N86UE.PH@("`@("`@
M(&UY("1C;60@/2`D=&UP+3YF:6QE;F%M92`N("<@/B]D978O;G5L;"`R/B8Q
M("8G.PH@("`@("`@(&-L;W-E("1T;7`["B`@("`@("`@<WES=&5M*"1C;60I
M.PH@("`@("`@(&]U=',H<7$H4W!A=VYE9"!B86-K9W)O=6YD('!R;V-E<W,@
M=&\@<&5R9F]R;2!C;&5A;G5P.B`I"B`@("`@("`@("`@("`N("1T;7`M/F9I
M;&5N86UE*3L*("`@('T*?2!]"@I"14=)3B!["B`@("!);G1E<FYA;',Z.E!!
M4CHZ0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PH*
M("`@(&5V86P@>PH*7W!A<E]I;FET7V5N=B@I.PH*:68@*&5X:7-T<R`D14Y6
M>U!!4E]!4D=67S!](&%N9"`D14Y6>U!!4E]!4D=67S!]("D@>PH@("`@0$%2
M1U8@/2!M87`@)$5.5GLB4$%27T%21U9?)%\B?2P@*#$@+BX@)$5.5GM005)?
M05)'0WT@+2`Q*3L*("`@("0P(#T@)$5.5GM005)?05)'5E\P?3L*?0IE;'-E
M('L*("`@(&9O<B`H:V5Y<R`E14Y6*2!["B`@("`@("`@9&5L971E("1%3E9[
M)%]](&EF("]>4$%27T%21U9?+SL*("`@('T*?0H*;7D@)'%U:65T(#T@(21%
M3E9[4$%27T1%0E5'?3L*"B,@9FEX("1P<F]G;F%M92!I9B!I;G9O:V5D(&9R
M;VT@4$%42`IM>2`E0V]N9FEG(#T@*`H@("`@<&%T:%]S97`@("`@/3X@*"1>
M3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"B`@("!?97AE("`@("`@("`]
M/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@
M)R<I+`H@("`@7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@
M/R`G7%PG(#H@)R\G*2P**3L*"E]S971?<')O9VYA;64H*3L*7W-E=%]P87)?
M=&5M<"@I.PH*(R!-86=I8R!S=')I;F<@8VAE8VMI;F<@86YD(&5X=')A8W1I
M;F<@8G5N9&QE9"!M;V1U;&5S('M[>PIM>2`H)'-T87)T7W!O<RP@)&1A=&%?
M<&]S*3L*>PH@("`@;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["@H@
M("`@(R!#:&5C:R!F:6QE('1Y<&4L(&=E="!S=&%R="!O9B!D871A('-E8W1I
M;VX@>WM["B`@("!O<&5N(%]&2"P@)SPG+"`D<')O9VYA;64@;W(@;&%S=#L*
M("`@(&)I;FUO9&4H7T9(*3L*"B`@("!M>2`D8G5F.PH@("`@<V5E:R!?1D@L
M("TX+"`R.PH@("`@<F5A9"!?1D@L("1B=68L(#@["B`@("!L87-T('5N;&5S
M<R`D8G5F(&5Q(")<;E!!4BYP;5QN(CL*"B`@("!S965K(%]&2"P@+3$R+"`R
M.PH@("`@<F5A9"!?1D@L("1B=68L(#0["B`@("!S965K(%]&2"P@+3$R("T@
M=6YP86-K*").(BP@)&)U9BDL(#(["B`@("!R96%D(%]&2"P@)&)U9BP@-#L*
M"B`@("`D9&%T85]P;W,@/2`H=&5L;"!?1D@I("T@-#L*("`@(",@?7U]"@H@
M("`@(R!%>'1R86-T:6YG(&5A8V@@9FEL92!I;G1O(&UE;6]R>2![>WL*("`@
M(&UY("5R97%U:7)E7VQI<W0["B`@("!W:&EL92`H)&)U9B!E<2`B1DE,12(I
M('L*("`@("`@("!R96%D(%]&2"P@)&)U9BP@-#L*("`@("`@("!R96%D(%]&
M2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["@H@("`@("`@(&UY("1F=6QL
M;F%M92`]("1B=68["B`@("`@("`@;W5T<RAQ<2A5;G!A8VMI;F<@9FEL92`B
M)&9U;&QN86UE(BXN+BDI.PH@("`@("`@(&UY("1C<F,@/2`H("1F=6QL;F%M
M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968["B`@("`@
M("`@;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_.BXJ+RD_
M*"XJ*2A<+BXJ*7PI.PH*("`@("`@("!R96%D(%]&2"P@)&)U9BP@-#L*("`@
M("`@("!R96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["@H@("`@
M("`@(&EF("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<+B@_.G!M?'!L
M?&EX?&%L*20O:2D@>PH@("`@("`@("`@("!M>2`H)&]U="P@)&9I;&5N86UE
M*2`](%]T96UP9FEL92@D97AT+"`D8W)C*3L*("`@("`@("`@("`@:68@*"1O
M=70I('L*("`@("`@("`@("`@("`@(&)I;FUO9&4H)&]U="D["B`@("`@("`@
M("`@("`@("!P<FEN="`D;W5T("1B=68["B`@("`@("`@("`@("`@("!C;&]S
M92`D;W5T.PH@("`@("`@("`@("`@("`@8VAM;V0@,#<U-2P@)&9I;&5N86UE
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@("1005(Z.DAE879Y.CI&=6QL
M0V%C:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M93L*("`@("`@("`@("`@)%!!
M4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA;65](#T@)&9U;&QN86UE.PH@
M("`@("`@('T*("`@("`@("!E;'-I9B`H("1F=6QL;F%M92`]?B!M?%XO/W-H
M;&EB+WP@86YD(&1E9FEN960@)$5.5GM005)?5$5-4'T@*2!["B`@("`@("`@
M("`@(",@<VAO=6QD(&)E(&UO=F5D('1O(%]T96UP9FEL92@I"B`@("`@("`@
M("`@(&UY("1F:6QE;F%M92`]("(D14Y6>U!!4E]414U0?2\D8F%S96YA;64D
M97AT(CL*("`@("`@("`@("`@;W5T<R@B4TA,24(Z("1F:6QE;F%M95QN(BD[
M"B`@("`@("`@("`@(&]P96X@;7D@)&]U="P@)SXG+"`D9FEL96YA;64@;W(@
M9&EE("0A.PH@("`@("`@("`@("!B:6YM;V1E*"1O=70I.PH@("`@("`@("`@
M("!P<FEN="`D;W5T("1B=68["B`@("`@("`@("`@(&-L;W-E("1O=70["B`@
M("`@("`@?0H@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`D<F5Q=6ER95]L
M:7-T>R1F=6QL;F%M97T@/0H@("`@("`@("`@("`D4$%2.CI(96%V>3HZ36]D
M=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*("`@("`@("`@("`@("`@(&)U9B`]
M/B`D8G5F+`H@("`@("`@("`@("`@("`@8W)C(#T^("1C<F,L"B`@("`@("`@
M("`@("`@("!N86UE(#T^("1F=6QL;F%M92P*("`@("`@("`@("`@?3L*("`@
M("`@("!]"B`@("`@("`@<F5A9"!?1D@L("1B=68L(#0["B`@("!]"B`@("`C
M('U]?0H*("`@(&QO8V%L($!)3D,@/2`H<W5B('L*("`@("`@("!M>2`H)'-E
M;&8L("1M;V1U;&4I(#T@0%\["@H@("`@("`@(')E='5R;B!I9B!R968@)&UO
M9'5L92!O<B`A)&UO9'5L93L*"B`@("`@("`@;7D@)&9I;&5N86UE(#T@9&5L
M971E("1R97%U:7)E7VQI<W1[)&UO9'5L97T@?'P@9&\@>PH@("`@("`@("`@
M("!M>2`D:V5Y.PH@("`@("`@("`@("!F;W)E86-H("AK97ES("5R97%U:7)E
M7VQI<W0I('L*("`@("`@("`@("`@("`@(&YE>'0@=6YL97-S("]<421M;V1U
M;&5<120O.PH@("`@("`@("`@("`@("`@)&ME>2`]("1?.R!L87-T.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@(&1E;&5T92`D<F5Q=6ER95]L:7-T>R1K
M97E](&EF(&1E9FEN960H)&ME>2D["B`@("`@("`@?2!O<B!R971U<FX["@H@
M("`@("`@("1)3D-[)&UO9'5L97T@/2`B+VQO861E<B\D9FEL96YA;64O)&UO
M9'5L92(["@H@("`@("`@(&EF("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN
M960H)DE/.CI&:6QE.CIN97<I*2!["B`@("`@("`@("`@(&UY("1F:"`]($E/
M.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@)"$["B`@("`@("`@("`@(&)I
M;FUO9&4H)&9H*3L*("`@("`@("`@("`@<')I;G0@)&9H("1F:6QE;F%M92T^
M>V)U9GT["B`@("`@("`@("`@('-E96LH)&9H+"`P+"`P*3L*("`@("`@("`@
M("`@<F5T=7)N("1F:#L*("`@("`@("!]"B`@("`@("`@96QS92!["B`@("`@
M("`@("`@(&UY("@D;W5T+"`D;F%M92D@/2!?=&5M<&9I;&4H)RYP;2<L("1F
M:6QE;F%M92T^>V-R8WTI.PH@("`@("`@("`@("!I9B`H)&]U="D@>PH@("`@
M("`@("`@("`@("`@8FEN;6]D92@D;W5T*3L*("`@("`@("`@("`@("`@('!R
M:6YT("1O=70@)&9I;&5N86UE+3Y[8G5F?3L*("`@("`@("`@("`@("`@(&-L
M;W-E("1O=70["B`@("`@("`@("`@('T*("`@("`@("`@("`@;W!E;B!M>2`D
M9F@L("<\)RP@)&YA;64@;W(@9&EE("0A.PH@("`@("`@("`@("!B:6YM;V1E
M*"1F:"D["B`@("`@("`@("`@(')E='5R;B`D9F@["B`@("`@("`@?0H*("`@
M("`@("!D:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86YN;W0@9FEN9"`D
M;6]D=6QE(5QN(CL*("`@('TL($!)3D,I.PH*("`@(",@3F]W(&QO860@86QL
M(&)U;F1L960@9FEL97,@>WM["@H@("`@(R!I;FET:6%L:7IE('-H87)E9"!O
M8FIE8W0@<')O8V5S<VEN9PH@("`@<F5Q=6ER92!84TQO861E<CL*("`@(')E
M<75I<F4@4$%2.CI(96%V>3L*("`@(')E<75I<F4@0V%R<#HZ2&5A=GD["B`@
M("!R97%U:7)E($5X<&]R=&5R.CI(96%V>3L*("`@(%!!4CHZ2&5A=GDZ.E]I
M;FET7V1Y;F%L;V%D97(H*3L*"B`@("`C(&YO=R!L970G<R!T<GD@9V5T=&EN
M9R!H96QP97(@;6]D=6QE<R!F<F]M('=I=&AI;@H@("`@<F5Q=6ER92!)3SHZ
M1FEL93L*"B`@("`C(&QO860@<F5S="!O9B!T:&4@9W)O=7`@:6X*("`@('=H
M:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I
M6S!=*2!["B`@("`@("`@(VQO8V%L("1)3D-[)T-W9"YP;2=](#T@7U]&24Q%
M7U\@:68@)%Y/(&YE("=-4U=I;C,R)SL*("`@("`@("!U;FQE<W,@*"1)3D-[
M)&9I;&5N86UE?2!O<B`D9FEL96YA;64@/7X@+T)31%!!3B\I('L*("`@("`@
M("`@("`@(R!R97%U:7)E(&UO9'5L97,L(&1O(&]T:&5R(&5X96-U=&%B;&4@
M9FEL97,*("`@("`@("`@("`@:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I
M*2!["B`@("`@("`@("`@("`@("!R97%U:7)E("1F:6QE;F%M93L*("`@("`@
M("`@("`@?0H@("`@("`@("`@("!E;'-E('L*("`@("`@("`@("`@("`@(",@
M4VMI<"!!8W1I=F53=&%T92=S('-I=&5C=7-T;VUI>F4N<&P@9FEL93H*("`@
M("`@("`@("`@("`@(&1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^
M("]S:71E8W5S=&]M:7IE7"YP;"0O.PH@("`@("`@("`@("!]"B`@("`@("`@
M?0H@("`@("`@(&1E;&5T92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T["B`@
M("!]"@H@("`@(R!]?7T*"B`@("!L87-T('5N;&5S<R`D8G5F(&5Q(")02UPP
M,#-<,#`T(CL*("`@("1S=&%R=%]P;W,@/2`H=&5L;"!?1D@I("T@-#L*?0HC
M('U]?0H*(R!!<F=U;65N="!P<F]C97-S:6YG('M[>PIM>2!`<&%R7V%R9W,[
M"FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H95]N86UE*3L*"F1E
M;&5T92`D14Y6>U!!4E]!4%!?4D554T5].R`C('-A;FET:7IE("A2155312!M
M87D@8F4@82!S96-U<FET>2!P<F]B;&5M*0H*)'%U:65T(#T@,"!U;FQE<W,@
M)$5.5GM005)?1$5"54=].PHC($1O;B=T('-W86QL;W<@87)G=6UE;G1S(&9O
M<B!C;VUP:6QE9"!E>&5C=71A8FQE<R!W:71H;W5T("TM<&%R+6]P=&EO;G,*
M:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N
M<R<@)B8@<VAI9G0I*2!["B`@("!M>2`E9&ES=%]C;60@/2!Q=R@*("`@("`@
M("!P("`@8FQI8E]T;U]P87(*("`@("`@("!I("`@:6YS=&%L;%]P87(*("`@
M("`@("!U("`@=6YI;G-T86QL7W!A<@H@("`@("`@(',@("!S:6=N7W!A<@H@
M("`@("`@('8@("!V97)I9GE?<&%R"B`@("`I.PH*("`@(",@:68@=&AE(&%P
M<"!I<R!I;G9O:V5D(&%S(")A<'!N86UE("TM<&%R+6]P=&EO;G,@+2UR975S
M92!04D]'4D%-($!04D]'7T%21U8B+`H@("`@(R!U<V4@=&AE(&%P<"!T;R!R
M=6X@=&AE(&=I=F5N('!E<FP@8V]D92!I;G-T96%D(&]F(&%N>71H:6YG(&9R
M;VT@=&AE"B`@("`C(&%P<"!I='-E;&8@*&)U="!S=&EL;"!S970@=7`@=&AE
M(&YO<FUA;"!A<'`@96YV:7)O;FUE;G0@86YD($!)3D,I"B`@("!I9B`H0$%2
M1U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PH@("`@("`@('-H:69T
M($!!4D=6.PH@("`@("`@("1%3E9[4$%27T%04%]2155317T@/2!S:&EF="!`
M05)'5CL*("`@('T*("`@(&5L<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U
M<@H*("`@("`@("!M>2!`861D7W1O7VEN8SL*("`@("`@("!W:&EL92`H0$%2
M1U8I('L*("`@("`@("`@("`@)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I
M=7-4=ETI*"XJ*2\@;W(@;&%S=#L*"B`@("`@("`@("`@(&EF("@D,2!E<2`G
M22<I('L*("`@("`@("`@("`@("`@('!U<V@@0&%D9%]T;U]I;F,L("0R.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G32<I('L*
M("`@("`@("`@("`@("`@(&5V86P@(G5S92`D,B(["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@96QS:68@*"0Q(&5Q("=!)RD@>PH@("`@("`@("`@("`@
M("`@=6YS:&EF="!`<&%R7V%R9W,L("0R.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@(&5L<VEF("@D,2!E<2`G3R<I('L*("`@("`@("`@("`@("`@("1O
M=70@/2`D,CL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-I9B`H)#$@
M97$@)V(G*2!["B`@("`@("`@("`@("`@("`D8G5N9&QE(#T@)W-I=&4G.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G0B<I('L*
M("`@("`@("`@("`@("`@("1B=6YD;&4@/2`G86QL)SL*("`@("`@("`@("`@
M?0H@("`@("`@("`@("!E;'-I9B`H)#$@97$@)W$G*2!["B`@("`@("`@("`@
M("`@("`D<75I970@/2`Q.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L
M<VEF("@D,2!E<2`G3"<I('L*("`@("`@("`@("`@("`@(&]P96X@)&QO9V9H
M+"`B/CXB+"`D,B!O<B!D:64@(EA86#H@0V%N;F]T(&]P96X@;&]G.B`D(2([
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS:68@*"0Q(&5Q("=4)RD@
M>PH@("`@("`@("`@("`@("`@)&-A8VAE7VYA;64@/2`D,CL*("`@("`@("`@
M("`@?0H*("`@("`@("`@("`@<VAI9G0H0$%21U8I.PH*("`@("`@("`@("`@
M:68@*&UY("1C;60@/2`D9&ES=%]C;61[)#%]*2!["B`@("`@("`@("`@("`@
M("!D96QE=&4@)$5.5GLG4$%27U1%35`G?3L*("`@("`@("`@("`@("`@(&EN
M:71?:6YC*"D["B`@("`@("`@("`@("`@("!R97%U:7)E(%!!4CHZ1&ES=#L*
M("`@("`@("`@("`@("`@("9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S
M($!!4D=6.PH@("`@("`@("`@("`@("`@)GLB4$%2.CI$:7-T.CHD8VUD(GTH
M)%\I(&9O<B!`05)'5CL*("`@("`@("`@("`@("`@(&5X:70["B`@("`@("`@
M("`@('T*("`@("`@("!]"@H@("`@("`@('5N<VAI9G0@0$E.0RP@0&%D9%]T
M;U]I;F,["B`@("!]"GT*"B,@6%A8("TM(&%D9"`M+7!A<BUD96)U9R!S=7!P
M;W)T(0H*(R!]?7T*"B,@3W5T<'5T(&UO9&4@*"U/*2!H86YD;&EN9R![>WL*
M:68@*"1O=70I('L*("`@('L*("`@("`@("`C;&]C86P@)$E.0WLG0W=D+G!M
M)WT@/2!?7T9)3$5?7R!I9B`D7D\@;F4@)TU35VEN,S(G.PH@("`@("`@(')E
M<75I<F4@24\Z.D9I;&4["B`@("`@("`@<F5Q=6ER92!!<F-H:79E.CI::7`[
M"B`@("!]"@H@("`@;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*("`@(&UY("1Z
M:7`["@H*("`@(&EF("AD969I;F5D("1P87(I('L*("`@("`@("!O<&5N(&UY
M("1F:"P@)SPG+"`D<&%R(&]R(&1I92`B0V%N;F]T(&9I;F0@)R1P87(G.B`D
M(2(["B`@("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@(&)L97-S*"1F:"P@
M)TE/.CI&:6QE)RD["@H@("`@("`@("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE
M=SL*("`@("`@("`H("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P
M87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"B`@("`@("`@("`@(&]R
M(&1I92`B4F5A9"`G)'!A<B<@97)R;W(Z("0A(CL*("`@('T*"@H@("`@;7D@
M)65N=B`](&1O('L*("`@("`@("!I9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D
M>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@>PH@("`@("`@("`@("`D;65T
M82`]?B!S+RXJ7G!A<CHD+R]M<SL*("`@("`@("`@("`@)&UE=&$@/7X@<R]>
M7%,N*B\O;7,["B`@("`@("`@("`@("1M971A(#U^("]>("`H6UXZ72LI.B`H
M+BLI)"]M9SL*("`@("`@("!]"B`@("!].PH*("`@(",@3W!E;B!I;G!U="!A
M;F0@;W5T<'5T(&9I;&5S('M[>PH@("`@;&]C86P@)"\@/2!<-#L*"B`@("!I
M9B`H9&5F:6YE9"`D<&%R*2!["B`@("`@("`@;W!E;B!005(L("<\)RP@)'!A
M<B!O<B!D:64@(B0A.B`D<&%R(CL*("`@("`@("!B:6YM;V1E*%!!4BD["B`@
M("`@("`@9&EE("(D<&%R(&ES(&YO="!A(%!!4B!F:6QE(B!U;FQE<W,@/%!!
M4CX@97$@(E!+7#`P,UPP,#0B.PH@("`@?0H*("`@($-R96%T95!A=&@H)&]U
M="D@.PH@("`@"B`@("!M>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`H@("`@("`@
M("1O=70L"B`@("`@("`@24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE
M.CI/7U=23TY,62@I('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P*("`@("`@("`P
M-S<W+`H@("`@*2!O<B!D:64@)"$["B`@("!B:6YM;V1E*"1F:"D["@H@("`@
M)"\@/2`H9&5F:6YE9"`D9&%T85]P;W,I(#\@7"1D871A7W!O<R`Z('5N9&5F
M.PH@("`@<V5E:R!?1D@L(#`L(#`["B`@("!M>2`D;&]A9&5R(#T@<V-A;&%R
M(#Q?1D@^.PH@("`@:68@*"$D14Y6>U!!4E]615)"051)37T@86YD("1L;V%D
M97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["B`@("`@("`@<F5Q=6ER92!005(Z
M.D9I;'1E<CHZ4&]D4W1R:7`["B`@("`@("`@4$%2.CI&:6QT97(Z.E!O9%-T
M<FEP+3YN97<M/F%P<&QY*%PD;&]A9&5R+"`D,"D*("`@('T*("`@(&9O<F5A
M8V@@;7D@)&ME>2`H<V]R="!K97ES("5E;G8I('L*("`@("`@("!M>2`D=F%L
M(#T@)&5N=GLD:V5Y?2!O<B!N97AT.PH@("`@("`@("1V86P@/2!E=F%L("1V
M86P@:68@)'9A;"`]?B`O7ELG(ETO.PH@("`@("`@(&UY("1M86=I8R`](")?
M7T5.5E]005)?(B`N('5C*"1K97DI("X@(E]?(CL*("`@("`@("!M>2`D<V5T
M(#T@(E!!4E\B("X@=6,H)&ME>2D@+B`B/21V86PB.PH@("`@("`@("1L;V%D
M97(@/7X@<WLD;6%G:6,H("LI?7L*("`@("`@("`@("`@)&UA9VEC("X@)'-E
M="`N("@G("<@>"`H;&5N9W1H*"0Q*2`M(&QE;F=T:"@D<V5T*2DI"B`@("`@
M("`@?65G.PH@("`@?0H@("`@)&9H+3YP<FEN="@D;&]A9&5R*3L*("`@("0O
M(#T@=6YD968["B`@("`C('U]?0H*("`@(",@5W)I=&4@8G5N9&QE9"!M;V1U
M;&5S('M[>PH@("`@:68@*"1B=6YD;&4I('L*("`@("`@("!R97%U:7)E(%!!
M4CHZ2&5A=GD["B`@("`@("`@4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E
M<B@I.PH@("`@("`@(&EN:71?:6YC*"D["@H@("`@("`@(')E<75I<F5?;6]D
M=6QE<R@I.PH*("`@("`@("!M>2!`:6YC(#T@<V]R="!["B`@("`@("`@("`@
M(&QE;F=T:"@D8BD@/#T^(&QE;F=T:"@D82D*("`@("`@("!](&=R97`@>PH@
M("`@("`@("`@("`A+T)31%!!3B\*("`@("`@("!](&=R97`@>PH@("`@("`@
M("`@("`H)&)U;F1L92!N92`G<VET92<I(&]R"B`@("`@("`@("`@("@D7R!N
M92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD"B`@("`@("`@("`@
M("`D7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PH@("`@("`@
M('T@0$E.0SL*"B`@("`@("`@(R!&:6QE(&5X:7-T<R!T97-T(&%D9&5D('1O
M(&9I>"!25"`C-#$W.3`Z"B`@("`@("`@(R!&=6YN>2P@;F]N+65X:7-T:6YG
M(&5N=')Y(&EN(%\\+BXN+F%U=&\O0V]M<')E<W,O4F%W+UIL:6(O875T;W-P
M;&ET+FEX+@H@("`@("`@(",@5&AI<R!I<R!A(&)A;F0M86ED(&9I>"!W:71H
M(&YO(&1E97!E<B!G<F%S<"!O9B!T:&4@:7-S=64N"B`@("`@("`@(R!3;VUE
M8F]D>2!P;&5A<V4@9V\@=&AR;W5G:"!T:&4@<&%I;B!O9B!U;F1E<G-T86YD
M:6YG('=H870G<R!H87!P96YI;F<L"B`@("`@("`@(R!)(&9A:6QE9"X@+2T@
M4W1E9F9E;@H@("`@("`@(&UY("5F:6QE<SL*("`@("`@("`O7E\\*"XK*20O
M(&%N9"`M92`D,2!A;F0@)&9I;&5S>R0Q?2LK(&9O<B!K97ES("4Z.CL*("`@
M("`@("`D9FEL97-[)%]]*RL@9F]R('9A;'5E<R`E24Y#.PH*("`@("`@("!M
M>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L*("`@("`@
M("!M>2`E=W)I='1E;CL*"B`@("`@("`@9F]R96%C:"`H<V]R="!K97ES("5F
M:6QE<RD@>PH@("`@("`@("`@("!M>2`H)&YA;64L("1F:6QE*3L*"B`@("`@
M("`@("`@(&9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PH@("`@("`@("`@("`@
M("`@:68@*"1N86UE(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD7WTI('L*
M("`@("`@("`@("`@("`@("`@("`D9FEL92`]("1?.PH@("`@("`@("`@("`@
M("`@("`@(&QA<W0["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@
M("!E;'-I9B`H+UXH7%$D9&ER7$5<+R@N*EM>0V-=*2E<6B]I*2!["B`@("`@
M("`@("`@("`@("`@("`@*"1F:6QE+"`D;F%M92D@/2`H)#$L("0R*3L*("`@
M("`@("`@("`@("`@("`@("!L87-T.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@96QS:68@*&TA7B]L;V%D97(O6UXO72LO*"XJ6UY#8UTI
M7%HA*2!["B`@("`@("`@("`@("`@("`@("`@:68@*&UY("1R968@/2`D4$%2
M.CI(96%V>3HZ36]D=6QE0V%C:&5[)#%]*2!["B`@("`@("`@("`@("`@("`@
M("`@("`@("@D9FEL92P@)&YA;64I(#T@*"1R968L("0Q*3L*("`@("`@("`@
M("`@("`@("`@("`@("`@;&%S=#L*("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("`@("`@96QS:68@*"UF("(D9&ER+R0Q(BD@>PH@("`@
M("`@("`@("`@("`@("`@("`@("`H)&9I;&4L("1N86UE*2`]("@B)&1I<B\D
M,2(L("0Q*3L*("`@("`@("`@("`@("`@("`@("`@("`@;&%S=#L*("`@("`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M('T*"B`@("`@("`@("`@(&YE>'0@=6YL97-S(&1E9FEN960@)&YA;64@86YD
M(&YO="`D=W)I='1E;GLD;F%M97TK*SL*("`@("`@("`@("`@;F5X="!I9B`A
M<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"\["B`@
M("`@("`@("`@(&]U=',H(&IO:6X@(B(L"B`@("`@("`@("`@("`@("!Q<2A0
M86-K:6YG("(I+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4L
M"B`@("`@("`@("`@("`@("!Q<2@B+BXN*0H@("`@("`@("`@("`I.PH*("`@
M("`@("`@("`@;7D@)&-O;G1E;G0["B`@("`@("`@("`@(&EF("AR968H)&9I
M;&4I*2!["B`@("`@("`@("`@("`@("`D8V]N=&5N="`]("1F:6QE+3Y[8G5F
M?3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-E('L*("`@("`@("`@
M("`@("`@(&]P96X@1DE,12P@)SPG+"`D9FEL92!O<B!D:64@(D-A;B=T(&]P
M96X@)&9I;&4Z("0A(CL*("`@("`@("`@("`@("`@(&)I;FUO9&4H1DE,12D[
M"B`@("`@("`@("`@("`@("`D8V]N=&5N="`](#Q&24Q%/CL*("`@("`@("`@
M("`@("`@(&-L;W-E($9)3$4["@H@("`@("`@("`@("`@("`@4$%2.CI&:6QT
M97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4I"B`@
M("`@("`@("`@("`@("`@("`@:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@
M)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PH*("`@("`@("`@("`@("`@
M(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0M/FYE=RT^87!P;'DH7"1C;VYT
M96YT+"`D9FEL92P@)&YA;64I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@
M("!O=71S*'%Q*%=R:71T96X@87,@(B1N86UE(BDI.PH@("`@("`@("`@("`D
M9F@M/G!R:6YT*")&24Q%(BD["B`@("`@("`@("`@("1F:"T^<')I;G0H<&%C
M:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2D["B`@("`@("`@("`@("1F:"T^
M<')I;G0H<W!R:6YT9B@*("`@("`@("`@("`@("`@("(E,#AX+R5S(BP@07)C
M:&EV93HZ6FEP.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M90H@("`@
M("`@("`@("`I*3L*("`@("`@("`@("`@)&9H+3YP<FEN="AP86-K*"=.)RP@
M;&5N9W1H*"1C;VYT96YT*2DI.PH@("`@("`@("`@("`D9F@M/G!R:6YT*"1C
M;VYT96YT*3L*("`@("`@("!]"B`@("!]"B`@("`C('U]?0H*("`@(",@3F]W
M('=R:71E(&]U="!T:&4@4$%2(&%N9"!M86=I8R!S=')I;F=S('M[>PH@("`@
M)'II<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H*2!I9B`D>FEP.PH*("`@("1C
M86-H95]N86UE(#T@<W5B<W1R("1C86-H95]N86UE+"`P+"`T,#L*("`@(&EF
M("@A)&-A8VAE7VYA;64@86YD(&UY("1M=&EM92`]("AS=&%T*"1O=70I*5LY
M72D@>PH@("`@("`@(&UY("1C='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z
M.E-(03L@1&EG97-T.CI32$$M/FYE=R@Q*2!]"B`@("`@("`@("`@('Q\(&5V
M86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN97<@
M?0H@("`@("`@("`@("!\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.DU$-3L@
M1&EG97-T.CI-1#4M/FYE=R!].PH*("`@("`@("`C(%=O<FMA<F]U;F0@9F]R
M(&)U9R!I;B!$:6=E<W0Z.E-(02`U+C,X(&%N9"`U+C,Y"B`@("`@("`@;7D@
M)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]
M('Q\(#`["B`@("`@("`@:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@
M)'-H85]V97)S:6]N(&5Q("<U+C,Y)RD@>PH@("`@("`@("`@("`D8W1X+3YA
M9&1F:6QE*"1O=70L(")B(BD@:68@*"1C='@I.PH@("`@("`@('T*("`@("`@
M("!E;'-E('L*("`@("`@("`@("`@:68@*"1C='@@86YD(&]P96XH;7D@)&9H
M+"`B/"1O=70B*2D@>PH@("`@("`@("`@("`@("`@8FEN;6]D92@D9F@I.PH@
M("`@("`@("`@("`@("`@)&-T>"T^861D9FEL92@D9F@I.PH@("`@("`@("`@
M("`@("`@8VQO<V4H)&9H*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@
M("`@("`@)&-A8VAE7VYA;64@/2`D8W1X(#\@)&-T>"T^:&5X9&EG97-T(#H@
M)&UT:6UE.PH@("`@?0H@("`@)&-A8VAE7VYA;64@+CT@(EPP(B!X("@T,2`M
M(&QE;F=T:"`D8V%C:&5?;F%M92D["B`@("`D8V%C:&5?;F%M92`N/2`B0T%#
M2$4B.PH@("`@)&9H+3YP<FEN="@D8V%C:&5?;F%M92D["B`@("`D9F@M/G!R
M:6YT*'!A8VLH)TXG+"`D9F@M/G1E;&P@+2!L96YG=&@H)&QO861E<BDI*3L*
M("`@("1F:"T^<')I;G0H(EQN4$%2+G!M7&XB*3L*("`@("1F:"T^8VQO<V4[
M"B`@("!C:&UO9"`P-S4U+"`D;W5T.PH@("`@(R!]?7T*"B`@("!E>&ET.PI]
M"B,@?7U]"@HC(%!R97!A<F4@)'!R;V=N86UE(&EN=&\@4$%2(&9I;&4@8V%C
M:&4@>WM["GL*("`@(&QA<W0@=6YL97-S(&1E9FEN960@)'-T87)T7W!O<SL*
M"B`@("!?9FEX7W!R;V=N86UE*"D["@H@("`@(R!.;W<@;&]A9"!T:&4@4$%2
M(&9I;&4@86YD('!U="!I="!I;G1O(%!!4CHZ3&EB0V%C:&4@>WM["B`@("!R
M97%U:7)E(%!!4CL*("`@(%!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H
M*3L*"@H@("`@>PH@("`@("`@("-L;V-A;"`D24Y#>R=#=V0N<&TG?2`](%]?
M1DE,15]?(&EF("1>3R!N92`G35-7:6XS,B<["B`@("`@("`@<F5Q=6ER92!&
M:6QE.CI&:6YD.PH@("`@("`@(')E<75I<F4@07)C:&EV93HZ6FEP.PH@("`@
M?0H@("`@;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PH@("`@;7D@)&9H
M(#T@24\Z.D9I;&4M/FYE=SL*("`@("1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I
M+"`G<B<I(&]R(&1I92`B)"$Z("1`(CL*("`@("1Z:7`M/G)E861&<F]M1FEL
M94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/
M2R@I(&]R(&1I92`B)"$Z("1`(CL*"B`@("!P=7-H($!005(Z.DQI8D-A8VAE
M+"`D>FEP.PH@("`@)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`[
M"@H@("`@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*("`@(&]U=',H<7$H
M7"1%3E9[4$%27U1%35!](#T@(B1%3E9[4$%27U1%35!](BDI.PH*("`@(&EF
M("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD(&)E('-E="!A
M="!T:&ES('!O:6YT(0H@("`@("`@(&9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z
M:7`M/FUE;6)E<G,@*2!["B`@("`@("`@("`@(&YE>'0@:68@)&UE;6)E<BT^
M:7-$:7)E8W1O<GD["B`@("`@("`@("`@(&UY("1M96UB97)?;F%M92`]("1M
M96UB97(M/F9I;&5.86UE.PH@("`@("`@("`@("!N97AT('5N;&5S<R`D;65M
M8F5R7VYA;64@/7X@;7L*("`@("`@("`@("`@("`@(%X*("`@("`@("`@("`@
M("`@("\_<VAL:6(O"B`@("`@("`@("`@("`@("`H/SHD0V]N9FEG.CI#;VYF
M:6=[=F5R<VEO;GTO*3\*("`@("`@("`@("`@("`@("@_.B1#;VYF:6<Z.D-O
M;F9I9WMA<F-H;F%M97TO*3\*("`@("`@("`@("`@("`@("A;7B]=*RD*("`@
M("`@("`@("`@("`@("0*("`@("`@("`@("`@?7@["B`@("`@("`@("`@(&UY
M("1E>'1R86-T7VYA;64@/2`D,3L*("`@("`@("`@("`@;7D@)&1E<W1?;F%M
M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R
M86-T7VYA;64I.PH@("`@("`@("`@("!I9B`H+68@)&1E<W1?;F%M92`F)B`M
M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PH@("`@("`@
M("`@("`@("`@;W5T<RAQ<2A3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S:6YC
M92!I="!A;')E861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M92(I*3L*("`@("`@
M("`@("`@?2!E;'-E('L*("`@("`@("`@("`@("`@(&]U=',H<7$H17AT<F%C
M=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M92(I*3L*("`@("`@
M("`@("`@("`@("1M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N
M86UE*3L*("`@("`@("`@("`@("`@(&-H;6]D*#`U-34L("1D97-T7VYA;64I
M(&EF("1>3R!E<2`B:'!U>"(["B`@("`@("`@("`@('T*("`@("`@("!]"B`@
M("!]"B`@("`C('U]?0I]"B,@?7U]"@HC($EF('1H97)E)W,@;F\@;6%I;BYP
M;"!T;R!R=6XL('-H;W<@=7-A9V4@>WM["G5N;&5S<R`H)%!!4CHZ3&EB0V%C
M:&5[)'!R;V=N86UE?2D@>PH@("`@9&EE(#P\("(N(B!U;FQE<W,@0$%21U8[
M"E5S86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE
M(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*("`@("`@("0P(%L@+4)\
M+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*("`@("1%3E9[4$%27U!23T=.
M04U%?2`]("1P<F]G;F%M92`]("0P(#T@<VAI9G0H0$%21U8I.PI]"B,@?7U]
M"@IS=6(@0W)E871E4&%T:"!["B`@("!M>2`H)&YA;64I(#T@0%\["B`@("`*
M("`@(')E<75I<F4@1FEL93HZ0F%S96YA;64["B`@("!M>2`H)&)A<V5N86UE
M+"`D<&%T:"P@)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N
M86UE+"`H)UPN+BHG*2D["B`@("`*("`@(')E<75I<F4@1FEL93HZ4&%T:#L*
M("`@(`H@("`@1FEL93HZ4&%T:#HZ;6MP871H*"1P871H*2!U;FQE<W,H+64@
M)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@97)R;W(*?0H*<W5B(')E<75I
M<F5?;6]D=6QE<R!["B`@("`C;&]C86P@)$E.0WLG0W=D+G!M)WT@/2!?7T9)
M3$5?7R!I9B`D7D\@;F4@)TU35VEN,S(G.PH*("`@(')E<75I<F4@;&EB.PH@
M("`@<F5Q=6ER92!$>6YA3&]A9&5R.PH@("`@<F5Q=6ER92!I;G1E9V5R.PH@
M("`@<F5Q=6ER92!S=')I8W0["B`@("!R97%U:7)E('=A<FYI;F=S.PH@("`@
M<F5Q=6ER92!V87)S.PH@("`@<F5Q=6ER92!#87)P.PH@("`@<F5Q=6ER92!#
M87)P.CI(96%V>3L*("`@(')E<75I<F4@17)R;F\["B`@("!R97%U:7)E($5X
M<&]R=&5R.CI(96%V>3L*("`@(')E<75I<F4@17AP;W)T97(["B`@("!R97%U
M:7)E($9C;G1L.PH@("`@<F5Q=6ER92!&:6QE.CI496UP.PH@("`@<F5Q=6ER
M92!&:6QE.CI3<&5C.PH@("`@<F5Q=6ER92!84TQO861E<CL*("`@(')E<75I
M<F4@0V]N9FEG.PH@("`@<F5Q=6ER92!)3SHZ2&%N9&QE.PH@("`@<F5Q=6ER
M92!)3SHZ1FEL93L*("`@(')E<75I<F4@0V]M<')E<W,Z.EIL:6(["B`@("!R
M97%U:7)E($%R8VAI=F4Z.EII<#L*("`@(')E<75I<F4@4$%2.PH@("`@<F5Q
M=6ER92!005(Z.DAE879Y.PH@("`@<F5Q=6ER92!005(Z.D1I<W0["B`@("!R
M97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*("`@(')E<75I<F4@4$%2
M.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*("`@(')E<75I<F4@871T<FEB=71E
M<SL*("`@(&5V86P@>R!R97%U:7)E($-W9"!].PH@("`@979A;"![(')E<75I
M<F4@5VEN,S(@?3L*("`@(&5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!]
M.PH@("`@979A;"![(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T[
M"B`@("!E=F%L('L@<F5Q=6ER92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R92!]
M.PH@("`@979A;"![(')E<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ
M<V-A;&%R('T["GT*"B,@5&AE($,@=F5R<VEO;B!O9B!T:&ES(&-O9&4@87!P
M96%R<R!I;B!M>6QD<B]M:W1M<&1I<BYC"B,@5&AI<R!C;V1E(&%L<V\@;&EV
M97,@:6X@4$%2.CI3971U<%1E;7`@87,@<V5T7W!A<E]T96UP7V5N=B$*<W5B
M(%]S971?<&%R7W1E;7`@>PH@("`@:68@*&1E9FEN960@)$5.5GM005)?5$5-
M4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PH@("`@("`@("1P
M87)?=&5M<"`]("0Q.PH@("`@("`@(')E='5R;CL*("`@('T*"B`@("!F;W)E
M86-H(&UY("1P871H("@*("`@("`@("`H;6%P("1%3E9[)%]]+"!Q=R@@4$%2
M7U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0(%1-4"`I*2P*("`@("`@("!Q
M=R@@0SI<7%1%35`@+W1M<"`N("D*("`@("D@>PH@("`@("`@(&YE>'0@=6YL
M97-S(&1E9FEN960@)'!A=&@@86YD("UD("1P871H(&%N9"`M=R`D<&%T:#L*
M("`@("`@("!M>2`D=7-E<FYA;64["B`@("`@("`@;7D@)'!W=6ED.PH@("`@
M("`@(",@9&]E<R!N;W0@=V]R:R!E=F5R>7=H97)E.@H@("`@("`@(&5V86P@
M>R@D<'=U:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@)#X[?3L*"B`@
M("`@("`@:68@*"!D969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*("`@
M("`@("`@("`@)'5S97)N86UE(#T@)E=I;C,R.CI,;V=I;DYA;64["B`@("`@
M("`@?0H@("`@("`@(&5L<VEF("AD969I;F5D("1P=W5I9"D@>PH@("`@("`@
M("`@("`D=7-E<FYA;64@/2`D<'=U:60["B`@("`@("`@?0H@("`@("`@(&5L
M<V4@>PH@("`@("`@("`@("`D=7-E<FYA;64@/2`D14Y6>U5315).04U%?2!\
M?"`D14Y6>U5315)]('Q\("=365-414TG.PH@("`@("`@('T*("`@("`@("`D
M=7-E<FYA;64@/7X@<R]<5R]?+V<["@H@("`@("`@(&UY("1S=&UP9&ER(#T@
M(B1P871H)$-O;F9I9WM?9&5L:6U]<&%R+21U<V5R;F%M92(["B`@("`@("`@
M;6MD:7(@)'-T;7!D:7(L(#`W-34["B`@("`@("`@:68@*"$D14Y6>U!!4E]#
M3$5!3GT@86YD(&UY("1M=&EM92`]("AS=&%T*"1P<F]G;F%M92DI6SE=*2![
M"B`@("`@("`@("`@(&]P96X@*&UY("1F:"P@(CPB+B`D<')O9VYA;64I.PH@
M("`@("`@("`@("!S965K("1F:"P@+3$X+"`R.PH@("`@("`@("`@("!S>7-R
M96%D("1F:"P@;7D@)&)U9BP@-CL*("`@("`@("`@("`@:68@*"1B=68@97$@
M(EPP0T%#2$4B*2!["B`@("`@("`@("`@("`@("!S965K("1F:"P@+34X+"`R
M.PH@("`@("`@("`@("`@("`@<WES<F5A9"`D9F@L("1B=68L(#0Q.PH@("`@
M("`@("`@("`@("`@)&)U9B`]?B!S+UPP+R]G.PH@("`@("`@("`@("`@("`@
M)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`D8G5F.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`@
M("`@;7D@)&-T>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E
M<W0Z.E-(02T^;F5W*#$I('T*("`@("`@("`@("`@("`@("`@("!\?"!E=F%L
M('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*
M("`@("`@("`@("`@("`@("`@("!\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z
M.DU$-3L@1&EG97-T.CI-1#4M/FYE=R!].PH*("`@("`@("`@("`@("`@(",@
M5V]R:V%R;W5N9"!F;W(@8G5G(&EN($1I9V5S=#HZ4TA!(#4N,S@@86YD(#4N
M,SD*("`@("`@("`@("`@("`@(&UY("1S:&%?=F5R<VEO;B`](&5V86P@>R`D
M1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PH@("`@("`@("`@("`@("`@
M:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q
M("<U+C,Y)RD@>PH@("`@("`@("`@("`@("`@("`@("1C='@M/F%D9&9I;&4H
M)'!R;V=N86UE+"`B8B(I(&EF("@D8W1X*3L*("`@("`@("`@("`@("`@('T*
M("`@("`@("`@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`@("`@("`@(&EF
M("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD<')O9VYA;64B*2D@>PH@("`@
M("`@("`@("`@("`@("`@("`@("!B:6YM;V1E*"1F:"D["B`@("`@("`@("`@
M("`@("`@("`@("`@("1C='@M/F%D9&9I;&4H)&9H*3L*("`@("`@("`@("`@
M("`@("`@("`@("`@8VQO<V4H)&9H*3L*("`@("`@("`@("`@("`@("`@("!]
M"B`@("`@("`@("`@("`@("!]"@H@("`@("`@("`@("`@("`@)'-T;7!D:7(@
M+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`H("1C='@@/R`D8W1X+3YH
M97AD:6=E<W0@.B`D;71I;64@*3L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!C;&]S92@D9F@I.PH@("`@("`@('T*("`@("`@("!E;'-E('L*("`@("`@
M("`@("`@)$5.5GM005)?0TQ%04Y](#T@,3L*("`@("`@("`@("`@)'-T;7!D
M:7(@+CT@(B1#;VYF:6=[7V1E;&EM?71E;7`M)"0B.PH@("`@("`@('T*"B`@
M("`@("`@)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*("`@("`@("!M:V1I
M<B`D<W1M<&1I<BP@,#<U-3L*("`@("`@("!L87-T.PH@("`@?0H*("`@("1P
M87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]4
M14U0?2`]?B`O*"XK*2\["GT*"G-U8B!?=&5M<&9I;&4@>PH@("`@;7D@*"1E
M>'0L("1C<F,I(#T@0%\["B`@("!M>2`H)&9H+"`D9FEL96YA;64I.PH*("`@
M("1F:6QE;F%M92`]("(D<&%R7W1E;7`O)&-R8R1E>'0B.PH*("`@(&EF("@D
M14Y6>U!!4E]#3$5!3GTI('L*("`@("`@("!U;FQI;FL@)&9I;&5N86UE(&EF
M("UE("1F:6QE;F%M93L*("`@("`@("!P=7-H($!T;7!F:6QE+"`D9FEL96YA
M;64["B`@("!]"B`@("!E;'-E('L*("`@("`@("!R971U<FX@*'5N9&5F+"`D
M9FEL96YA;64I(&EF("@M<B`D9FEL96YA;64I.PH@("`@?0H*("`@(&]P96X@
M)&9H+"`G/B<L("1F:6QE;F%M92!O<B!D:64@)"$["B`@("!B:6YM;V1E*"1F
M:"D["B`@("!R971U<FXH)&9H+"`D9FEL96YA;64I.PI]"@HC('-A;64@8V]D
M92!L:79E<R!I;B!005(Z.E-E='5P4')O9VYA;64Z.G-E=%]P<F]G;F%M90IS
M=6(@7W-E=%]P<F]G;F%M92!["B`@("!I9B`H9&5F:6YE9"`D14Y6>U!!4E]0
M4D]'3D%-17T@86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*
M("`@("`@("`D<')O9VYA;64@/2`D,3L*("`@('T*"B`@("`D<')O9VYA;64@
M?'P]("0P.PH*("`@(&EF("@D14Y6>U!!4E]414U0?2!A;F0@:6YD97@H)'!R
M;V=N86UE+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@>PH@("`@("`@("1P<F]G
M;F%M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1#
M;VYF:6=[7V1E;&EM?2D@*R`Q*3L*("`@('T*"B`@("!I9B`H(21%3E9[4$%2
M7U!23T=.04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM
M?2D@/CT@,"D@>PH@("`@("`@(&EF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O
M9VYA;64I('L*("`@("`@("`@("`@<F5T=7)N(&EF("US("1F:#L*("`@("`@
M("!]"B`@("`@("`@:68@*"US("(D<')O9VYA;64D0V]N9FEG>U]E>&5](BD@
M>PH@("`@("`@("`@("`D<')O9VYA;64@+CT@)$-O;F9I9WM?97AE?3L*("`@
M("`@("`@("`@<F5T=7)N.PH@("`@("`@('T*("`@('T*"B`@("!F;W)E86-H
M(&UY("1D:7(@*'-P;&ET("]<421#;VYF:6=[<&%T:%]S97!]7$4O+"`D14Y6
M>U!!5$A]*2!["B`@("`@("`@;F5X="!I9B!E>&ES=',@)$5.5GM005)?5$5-
M4'T@86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T["B`@("`@("`@)&1I<B`]
M?B!S+UQ1)$-O;F9I9WM?9&5L:6U]7$4D+R\["B`@("`@("`@*"@D<')O9VYA
M;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X
M97TB*2P@;&%S="D*("`@("`@("`@("`@:68@+7,@(B1D:7(D0V]N9FEG>U]D
M96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](CL*("`@("`@("`H*"1P<F]G
M;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I
M"B`@("`@("`@("`@(&EF("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N
M86UE(CL*("`@('T*?0H*<W5B(%]F:7A?<')O9VYA;64@>PH@("`@)#`@/2`D
M<')O9VYA;64@?'P]("1%3E9[4$%27U!23T=.04U%?3L*("`@(&EF("AI;F1E
M>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/"`P*2!["B`@("`@("`@
M)'!R;V=N86UE(#T@(BXD0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PH@("`@
M?0H*("`@(",@6%A8("T@:&%C:R!T;R!M86ME(%!71"!W;W)K"B`@("!M>2`D
M<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*
M("`@("`@("`@("`@("`@(#H@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_
M(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*("`@(&-H;VUP*"1P=V0I.PH@
M("`@)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D0V]N9FEG>U]D96QI;7U<
M12DO)'!W9"1#;VYF:6=[7V1E;&EM?2\["@H@("`@)$5.5GM005)?4%)/1TY!
M345](#T@)'!R;V=N86UE.PI]"@IS=6(@7W!A<E]I;FET7V5N=B!["B`@("!I
M9B`H("1%3E9[4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2!["B`@("`@("`@
M<F5T=7)N.PH@("`@?2!E;'-E('L*("`@("`@("`D14Y6>U!!4E])3DE424%,
M25I%1'T@/2`R.PH@("`@?0H*("`@(&9O<B`H<7<H(%-005=.140@5$5-4"!#
M3$5!3B!$14)51R!#04-(12!04D]'3D%-12!!4D=#($%21U9?,"`I("D@>PH@
M("`@("`@(&1E;&5T92`D14Y6>R=005)?)RXD7WT["B`@("!]"B`@("!F;W(@
M*'%W+R!435!$25(@5$5-4"!#3$5!3B!$14)51R`O*2!["B`@("`@("`@)$5.
M5GLG4$%27R<N)%]](#T@)$5.5GLG4$%27T=,3T)!3%\G+B1??2!I9B!E>&ES
M=',@)$5.5GLG4$%27T=,3T)!3%\G+B1??3L*("`@('T*"B`@("!M>2`D<&%R
M7V-L96%N(#T@(E]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@(CL*
M"B`@("!I9B`H)$5.5GM005)?5$5-4'TI('L*("`@("`@("!D96QE=&4@)$5.
M5GM005)?0TQ%04Y].PH@("`@?0H@("`@96QS:68@*"%E>&ES=',@)$5.5GM0
M05)?1TQ/0D%,7T-,14%.?2D@>PH@("`@("`@(&UY("1V86QU92`]('-U8G-T
M<B@D<&%R7V-L96%N+"`Q,B`K(&QE;F=T:"@B0TQ%04XB*2D["B`@("`@("`@
M)$5.5GM005)?0TQ%04Y](#T@)#$@:68@)'9A;'5E(#U^("]>4$%27T-,14%.
M/2A<4RLI+SL*("`@('T*?0H*<W5B(&]U=',@>PH@("`@<F5T=7)N(&EF("1Q
M=6EE=#L*("`@(&EF("@D;&]G9F@I('L*("`@("`@("!P<FEN="`D;&]G9F@@
M(D!?7&XB.PH@("`@?0H@("`@96QS92!["B`@("`@("`@<')I;G0@(D!?7&XB
M.PH@("`@?0I]"@IS=6(@:6YI=%]I;F,@>PH@("`@<F5Q=6ER92!#;VYF:6<[
M"B`@("!P=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z.D-O
M;F9I9WLD7WTL('%W*`H@("`@("`@(&%R8VAL:6)E>'`@<')I=FQI8F5X<"!S
M:71E87)C:&5X<"!S:71E;&EB97AP"B`@("`@("`@=F5N9&]R87)C:&5X<"!V
M96YD;W)L:6)E>'`*("`@("D["GT*"B,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(PHC(%1H92!M86EN('!A8VMA9V4@9F]R('-C<FEP="!E>&5C=71I;VX*
M"G!A8VMA9V4@;6%I;CL*"G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF
M4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*"F1I92!Q
M<2AP87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z
M($YO('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;BD*("`@('5N;&5S<R`M92`D
M<')O9VYA;64["@ID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D
M0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*"GT[
M"@HD.CI?7T524D]2(#T@)$`@:68@)$`["GT*"D-/4D4Z.F5X:70H)#$I(&EF
M("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z
M.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*"C$["@HC;&EN92`Q,#$Q"@I?7T5.
M1%]?"@````#_____%``````````!>E(``7@0`0,,!PB0`0``)````!P```"P
M'T``G`````!!#A"&`D,-!D*-`TN#!8P$`````````!0```!$````4"!``#@`
M````1`X0`````!0```!<````D"!``"(``````````````!0```!T````P"!`
M`#0``````````````"P```",`````"%``/`5````0@X01@X80@X@00XHA@6,
M!(T#C@)$#C!'#K@$@P8``"0```"\````\#9``-D`````2H\"C`5>#D".`XT$
MA@:#!P`````````<````Y````-`W0`!/`````$$.$$$.&(,#A@)'#C```!0`
M```$`0``(#A``!4`````1`X@`````!0````<`0``0#A``$T`````1`X0````
M`!0````T`0``D#A``!X`````1`X0`````!0```!,`0``L#A``,(`````2`X0
M@P(``!P```!D`0``@#E``$(!````2H,&C`19#K`!C@*-`X8%'````(0!``#0
M.D``3P````!!#A"#`D<.D`$````````T````I`$``"`[0``%`@```$(.$$0.
M&(X#CP)%#B!"#BA!#C"&!HP%C01$#CA$#E"#!P```````#0```#<`0``,#U`
M`!<!````0@X00@X8C@./`D4.($(.*(P%C01'#C!!#CA$#H`!@P>&!@``````
M%````!0"``!0/D``O@$```!$#D``````%````"P"```00$``(@````!$#A``
M````'````$0"``!`0$``X@````!!#A!!#AB#`X8"1PX@```4````9`(``#!!
M0`!M`````$X.((8"@P,<````?`(``*!!0`#P`0```$$.$$0.,(,"````````
M`#0```"<`@``D$-``*P!````0@X00@X80@X@0@XHC`6-!(X#CP))#C!!#CB#
M!X8&2@[@"0``````-````-0"``!`14``/`H```!"#A"/`DH.&$(.($(.*$$.
M,$$..$<.H(0"@P>&!HP%C02.`P`````<````#`,``(!/0`#)`````%8.P!",
M`H8#@P0``````!0````L`P``4%!```4``````````````!P```!$`P``8%!`
M`-P"````0@X03PX800X@@P2&`XP"%````&0#``!`4T``%```````````````
M%````'P#``!@4T``)P````!$#A```````````!@``````````7I2``%X$`$#
M#`<(D`$````````4````(````)!30``E`````$@.$(,"```!``````````$`
M`````````0`````````=`@````````$`````````)P(````````!````````
M`#4"`````````0````````!"`@````````$`````````9@(````````/````
M`````+`#````````#`````````#(&T````````T`````````N%-````````$
M`````````/@!0```````!0````````#(#D````````8`````````(`5`````
M```*`````````,P$````````"P`````````8`````````!4`````````````
M```````#`````````*C!4````````@````````"@!0```````!0`````````
M!P`````````7`````````"@60```````!P````````"H%$````````@`````
M````@`$````````)`````````!@`````````_O__;P````!H%$```````/__
M_V\``````@````````#P__]O`````)030```````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````__________\`
M`````````/__________`````````````````````)"_4```````````````
M`````````````/(;0````````AQ````````2'$```````"(<0```````,AQ`
M``````!"'$```````%(<0```````8AQ```````!R'$```````((<0```````
MDAQ```````"B'$```````+(<0```````PAQ```````#2'$```````.(<0```
M````\AQ````````"'4```````!(=0```````(AU````````R'4```````$(=
M0```````4AU```````!B'4```````'(=0```````@AU```````"2'4``````
M`*(=0```````LAU```````#"'4```````-(=0```````XAU```````#R'4``
M``````(>0```````$AY````````B'D```````#(>0```````0AY```````!2
M'D```````&(>0```````<AY```````""'D```````)(>0```````HAY`````
M``"R'D```````,(>0```````TAY```````#B'D```````/(>0````````A]`
M```````2'T```````"(?0```````,A]```````!"'T```````%(?0```````
M8A]```````!R'T```````((?0```````DA]```````"B'T`````````D1G)E
M94)31#H@<W)C+VQI8B]C<W4O8V]M;6]N+V-R=&)R86YD+F,L=B`Q+C8N,BXQ
M+C0N,2`R,#$P+S`V+S$T(#`R.C`Y.C`V(&ME;G-M:71H($5X<"`D`"1&<F5E
M0E-$.B!S<F,O;&EB+V-S=2]A;60V-"]C<G0Q+F,L=B`Q+C$U+C$P+C$N-"XQ
M(#(P,3`O,#8O,30@,#(Z,#DZ,#8@:V5N<VUI=&@@17AP("0`1T-#.B`H1TY5
M*2`T+C(N,2`R,#`W,#<Q.2`@6T9R965"4T1=``!'0T,Z("A'3E4I(#0N,BXQ
M(#(P,#<P-S$Y("!;1G)E94)31%T``$=#0SH@*$=.52D@-"XR+C$@,C`P-S`W
M,3D@(%M&<F5E0E-$70``1T-#.B`H1TY5*2`T+C(N,2`R,#`W,#<Q.2`@6T9R
M965"4T1=```N<VAS=')T86(`+FEN=&5R<``N;F]T92Y!0DDM=&%G`"YH87-H
M`"YD>6YS>6T`+F1Y;G-T<@`N9VYU+G9E<G-I;VX`+F=N=2YV97)S:6]N7W(`
M+G)E;&$N9'EN`"YR96QA+G!L=``N:6YI=``N=&5X=``N9FEN:0`N<F]D871A
M`"YE:%]F<F%M95]H9'(`+F1A=&$`+F5H7V9R86UE`"YD>6YA;6EC`"YC=&]R
M<P`N9'1O<G,`+FIC<@`N9V]T`"YB<W,`+F-O;6UE;G0`````````````````
M````````````````````````````````````````````````````````````
M``````````````L````!`````@````````#(`4```````,@!````````%0``
M``````````````````$````````````````````3````!P````(`````````
MX`%```````#@`0```````!@````````````````````$````````````````
M````(0````4````"`````````/@!0```````^`$````````H`P````````0`
M````````"``````````$`````````"<````+`````@`````````@!4``````
M`"`%````````J`D````````%`````0````@`````````&``````````O````
M`P````(`````````R`Y```````#(#@```````,P$```````````````````!
M````````````````````-P```/___V\"`````````)030```````E!,`````
M``#.``````````0``````````@`````````"`````````$0```#^__]O`@``
M``````!H%$```````&@4````````0``````````%`````@````@`````````
M``````````!3````!`````(`````````J!1```````"H%````````(`!````
M````!``````````(`````````!@`````````70````0````"`````````"@6
M0```````*!8```````"@!0````````0````+````"``````````8````````
M`&<````!````!@````````#(&T```````,@;````````$P``````````````
M``````0```````````````````!B`````0````8`````````W!M```````#<
M&P```````-`#```````````````````$`````````!``````````;0````$`
M```&`````````+`?0```````L!\````````(-```````````````````$```
M`````````````````',````!````!@````````"X4T```````+A3````````
M#@````````````````````0```````````````````!Y`````0````(`````
M````R%-```````#(4P````````T$```````````````````(````````````
M````````@0````$````"`````````-A70```````V%<````````(````````
M````````````!````````````````````(\````!`````P``````````8%``
M``````!@````````R%L``````````````````"````````````````````"5
M`````0````(`````````R+M0``````#(NP```````,@#````````````````
M```(````````````````````GP````8````#`````````)"_4```````D+\`
M``````#P`0````````4`````````"``````````0`````````*@````!````
M`P````````"`P5```````(#!````````$`````````````````````@`````
M``````````````"O`````0````,`````````D,%0``````"0P0```````!``
M```````````````````(````````````````````M@````$````#````````
M`*#!4```````H,$````````(````````````````````"```````````````
M`````+L````!`````P````````"HP5```````*C!````````^`$`````````
M``````````@`````````"`````````#`````"`````,`````````H,-0````
M``"@PP````````@%```````````````````@````````````````````Q0``
M``$`````````````````````````H,,```````!'`0``````````````````
M`0````````````````````$````#`````````````````````````.?$````
C````S@````````````````````$`````````````````````
